! Description:
!> @file
!!   Contains data for the Baran 2014 ice optical property parameterisation
!
!> @brief
!!   Contains data for the Baran 2014 ice optical property parameterisation
!
! Copyright:
!    This software was developed within the context of
!    the EUMETSAT Satellite Application Facility on
!    Numerical Weather Prediction (NWP SAF), under the
!    Cooperation Agreement dated 7 December 2016, between
!    EUMETSAT and the Met Office, UK, by one or more partners
!    within the NWP SAF. The partners in the NWP SAF are
!    the Met Office, ECMWF, DWD and MeteoFrance.
!
!    Copyright 2016, EUMETSAT, All Rights Reserved.
!
MODULE mod_rttov_baran2014_icldata

  USE parkind1, Only : jprb, jpim
  IMPLICIT NONE

  PRIVATE

  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_max_asym = 1._JPRB - 1.E-6_JPRB !< Maximum allowed asym value

  ! Baran database training limits
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_iwc_min  = 6.0000001e-06_JPRB  !< IWC minimum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_iwc_max  = 1.969466_JPRB       !< IWC maximum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_temp_min = 193.157_JPRB        !< Temperature minimum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_temp_max = 273.12701_JPRB      !< Temperature maximum

  ! Baran database dimensions
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2014_wn   = 105_JPIM !< Number of wavenumbers
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2014_abs  =   6_JPIM !< Number of coefs for abs parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2014_sca  =   6_JPIM !< Number of coefs for sca parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2014_bpr  =   3_JPIM !< Number of coefs for bpr parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2014_asym =   3_JPIM !< Number of coefs for asym parameterisation

  !> Baran database wavelengths
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_wvl(n_baran2014_wn) = (/ &
& 18.870_JPRB, 18.610_JPRB, 18.320_JPRB, 18.180_JPRB, 17.240_JPRB,  &
& 16.670_JPRB, 16.130_JPRB, 15.630_JPRB, 15.150_JPRB, 14.710_JPRB,  &
& 14.290_JPRB, 14.080_JPRB, 13.700_JPRB, 13.510_JPRB, 13.330_JPRB,  &
& 12.990_JPRB, 12.820_JPRB, 12.500_JPRB, 12.200_JPRB, 11.900_JPRB,  &
& 11.630_JPRB, 11.360_JPRB, 11.000_JPRB, 10.750_JPRB, 10.530_JPRB,  &
& 10.310_JPRB, 10.200_JPRB, 10.000_JPRB,  9.804_JPRB,  9.259_JPRB,  &
&  9.091_JPRB,  8.696_JPRB,  8.475_JPRB,  8.333_JPRB,  8.065_JPRB,  &
&  7.812_JPRB,  7.463_JPRB,  7.246_JPRB,  7.042_JPRB,  6.757_JPRB,  &
&  6.494_JPRB,  6.410_JPRB,  6.329_JPRB,  6.250_JPRB,  6.061_JPRB,  &
&  5.814_JPRB,  5.747_JPRB,  5.556_JPRB,  5.263_JPRB,  5.200_JPRB,  &
&  5.000_JPRB,  4.900_JPRB,  4.700_JPRB,  4.500_JPRB,  4.300_JPRB,  &
&  4.100_JPRB,  3.925_JPRB,  3.775_JPRB,  3.650_JPRB,  3.550_JPRB,  &
&  3.450_JPRB,  3.350_JPRB,  3.275_JPRB,  3.225_JPRB,  3.188_JPRB,  &
&  3.162_JPRB,  3.138_JPRB,  3.112_JPRB,  3.088_JPRB,  3.062_JPRB,  &
&  3.037_JPRB,  3.013_JPRB,  2.987_JPRB,  2.963_JPRB,  2.888_JPRB,  &
&  2.862_JPRB,  2.838_JPRB,  2.812_JPRB,  2.750_JPRB,  2.650_JPRB,  &
&  2.500_JPRB,  2.350_JPRB,  2.250_JPRB,  2.150_JPRB,  2.050_JPRB,  &
&  1.975_JPRB,  1.925_JPRB,  1.850_JPRB,  1.725_JPRB,  1.575_JPRB,  &
&  1.450_JPRB,  1.350_JPRB,  1.250_JPRB,  1.150_JPRB,  1.050_JPRB,  &
&  0.950_JPRB,  0.870_JPRB,  0.650_JPRB,  0.551_JPRB,  0.476_JPRB,  &
&  0.425_JPRB,  0.350_JPRB,  0.275_JPRB,  0.225_JPRB,  0.200_JPRB/)

  !> Baran database wavenumbers
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_wvn(n_baran2014_wn) =(/ &
&   529.94_JPRB,   537.35_JPRB,   545.85_JPRB,   550.05_JPRB,   580.05_JPRB,  &
&   599.88_JPRB,   619.96_JPRB,   639.80_JPRB,   660.07_JPRB,   679.81_JPRB,  &
&   699.79_JPRB,   710.23_JPRB,   729.93_JPRB,   740.19_JPRB,   750.19_JPRB,  &
&   769.82_JPRB,   780.03_JPRB,   800.00_JPRB,   819.67_JPRB,   840.34_JPRB,  &
&   859.85_JPRB,   880.28_JPRB,   909.09_JPRB,   930.23_JPRB,   949.67_JPRB,  &
&   969.93_JPRB,   980.39_JPRB,  1000.00_JPRB,  1019.99_JPRB,  1080.03_JPRB,  &
&  1099.99_JPRB,  1149.95_JPRB,  1179.94_JPRB,  1200.05_JPRB,  1239.93_JPRB,  &
&  1280.08_JPRB,  1339.94_JPRB,  1380.07_JPRB,  1420.05_JPRB,  1479.95_JPRB,  &
&  1539.88_JPRB,  1560.06_JPRB,  1580.03_JPRB,  1600.00_JPRB,  1649.89_JPRB,  &
&  1719.99_JPRB,  1740.04_JPRB,  1799.86_JPRB,  1900.06_JPRB,  1923.08_JPRB,  &
&  2000.00_JPRB,  2040.82_JPRB,  2127.66_JPRB,  2222.22_JPRB,  2325.58_JPRB,  &
&  2439.02_JPRB,  2547.77_JPRB,  2649.01_JPRB,  2739.73_JPRB,  2816.90_JPRB,  &
&  2898.55_JPRB,  2985.07_JPRB,  3053.44_JPRB,  3100.78_JPRB,  3136.76_JPRB,  &
&  3162.56_JPRB,  3186.74_JPRB,  3213.37_JPRB,  3238.34_JPRB,  3265.84_JPRB,  &
&  3292.72_JPRB,  3318.95_JPRB,  3347.84_JPRB,  3374.96_JPRB,  3462.60_JPRB,  &
&  3494.06_JPRB,  3523.61_JPRB,  3556.19_JPRB,  3636.36_JPRB,  3773.58_JPRB,  &
&  4000.00_JPRB,  4255.32_JPRB,  4444.44_JPRB,  4651.16_JPRB,  4878.05_JPRB,  &
&  5063.29_JPRB,  5194.80_JPRB,  5405.41_JPRB,  5797.10_JPRB,  6349.21_JPRB,  &
&  6896.55_JPRB,  7407.41_JPRB,  8000.00_JPRB,  8695.65_JPRB,  9523.81_JPRB,  &
& 10526.32_JPRB, 11494.25_JPRB, 15384.62_JPRB, 18162.00_JPRB, 21030.49_JPRB,  &
& 23529.41_JPRB, 28571.43_JPRB, 36363.64_JPRB, 44444.45_JPRB, 50000.00_JPRB/)

  !> Baran regression coefficients for absorption coef
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_regcoef_abs(n_baran2014_abs, n_baran2014_wn) = &
  RESHAPE( (/ &
&   0.8957424_JPRB,      0.0028839_JPRB,      1.1139646_JPRB,     -0.0000059_JPRB,     -0.0075856_JPRB,     -0.0004599_JPRB,  &
&   0.9425193_JPRB,      0.0025711_JPRB,      1.1090950_JPRB,     -0.0000055_JPRB,     -0.0079937_JPRB,     -0.0004620_JPRB,  &
&   0.9255278_JPRB,      0.0026001_JPRB,      1.1013478_JPRB,     -0.0000053_JPRB,     -0.0064838_JPRB,     -0.0004002_JPRB,  &
&   0.9814436_JPRB,      0.0021896_JPRB,      1.0976028_JPRB,     -0.0000046_JPRB,     -0.0071894_JPRB,     -0.0004105_JPRB,  &
&   1.1469902_JPRB,      0.0009641_JPRB,      1.0603993_JPRB,     -0.0000023_JPRB,     -0.0055842_JPRB,     -0.0002903_JPRB,  &
&   1.2191536_JPRB,      0.0000718_JPRB,      1.0267120_JPRB,      0.0000000_JPRB,     -0.0026449_JPRB,     -0.0001172_JPRB,  &
&   1.2459905_JPRB,     -0.0001171_JPRB,      1.0213101_JPRB,      0.0000003_JPRB,     -0.0024737_JPRB,     -0.0001023_JPRB,  &
&   1.3157977_JPRB,     -0.0005718_JPRB,      1.0105535_JPRB,      0.0000010_JPRB,     -0.0025265_JPRB,     -0.0000864_JPRB,  &
&   1.3631226_JPRB,     -0.0009360_JPRB,      0.9974717_JPRB,      0.0000017_JPRB,     -0.0016650_JPRB,     -0.0000361_JPRB,  &
&   1.4099897_JPRB,     -0.0013306_JPRB,      0.9836309_JPRB,      0.0000025_JPRB,     -0.0007009_JPRB,      0.0000189_JPRB,  &
&   1.4531765_JPRB,     -0.0016759_JPRB,      0.9712156_JPRB,      0.0000031_JPRB,      0.0001690_JPRB,      0.0000674_JPRB,  &
&   1.4689153_JPRB,     -0.0017990_JPRB,      0.9668884_JPRB,      0.0000034_JPRB,      0.0004712_JPRB,      0.0000840_JPRB,  &
&   1.4885591_JPRB,     -0.0019505_JPRB,      0.9614247_JPRB,      0.0000036_JPRB,      0.0008701_JPRB,      0.0001052_JPRB,  &
&   1.4950127_JPRB,     -0.0019984_JPRB,      0.9596485_JPRB,      0.0000037_JPRB,      0.0010052_JPRB,      0.0001120_JPRB,  &
&   1.4995788_JPRB,     -0.0020329_JPRB,      0.9582582_JPRB,      0.0000038_JPRB,      0.0011209_JPRB,      0.0001175_JPRB,  &
&   1.5072406_JPRB,     -0.0020810_JPRB,      0.9566000_JPRB,      0.0000038_JPRB,      0.0012364_JPRB,      0.0001227_JPRB,  &
&   1.5086196_JPRB,     -0.0020846_JPRB,      0.9564434_JPRB,      0.0000038_JPRB,      0.0012484_JPRB,      0.0001227_JPRB,  &
&   1.5078076_JPRB,     -0.0020608_JPRB,      0.9572758_JPRB,      0.0000038_JPRB,      0.0011849_JPRB,      0.0001180_JPRB,  &
&   1.5056791_JPRB,     -0.0020113_JPRB,      0.9597565_JPRB,      0.0000036_JPRB,      0.0009314_JPRB,      0.0001044_JPRB,  &
&   1.5018488_JPRB,     -0.0019366_JPRB,      0.9635905_JPRB,      0.0000034_JPRB,      0.0005294_JPRB,      0.0000836_JPRB,  &
&   1.4966949_JPRB,     -0.0018360_JPRB,      0.9690031_JPRB,      0.0000031_JPRB,     -0.0000553_JPRB,      0.0000542_JPRB,  &
&   1.4871268_JPRB,     -0.0016629_JPRB,      0.9774052_JPRB,      0.0000026_JPRB,     -0.0009211_JPRB,      0.0000091_JPRB,  &
&   1.4766723_JPRB,     -0.0013791_JPRB,      0.9947181_JPRB,      0.0000018_JPRB,     -0.0029866_JPRB,     -0.0000909_JPRB,  &
&   1.4657123_JPRB,     -0.0010976_JPRB,      1.0123997_JPRB,      0.0000009_JPRB,     -0.0051265_JPRB,     -0.0001937_JPRB,  &
&   1.4188293_JPRB,     -0.0007212_JPRB,      1.0285256_JPRB,      0.0000002_JPRB,     -0.0063685_JPRB,     -0.0002595_JPRB,  &
&   1.2835708_JPRB,     -0.0000073_JPRB,      1.0381428_JPRB,     -0.0000005_JPRB,     -0.0049136_JPRB,     -0.0002208_JPRB,  &
&   1.1902068_JPRB,      0.0005739_JPRB,      1.0487916_JPRB,     -0.0000013_JPRB,     -0.0044569_JPRB,     -0.0002230_JPRB,  &
&   1.0048250_JPRB,      0.0018939_JPRB,      1.0808504_JPRB,     -0.0000035_JPRB,     -0.0050175_JPRB,     -0.0003007_JPRB,  &
&   0.9017908_JPRB,      0.0027070_JPRB,      1.1048591_JPRB,     -0.0000051_JPRB,     -0.0062189_JPRB,     -0.0003860_JPRB,  &
&   0.7882541_JPRB,      0.0035644_JPRB,      1.1288267_JPRB,     -0.0000067_JPRB,     -0.0075752_JPRB,     -0.0004723_JPRB,  &
&   0.7658884_JPRB,      0.0037102_JPRB,      1.1292717_JPRB,     -0.0000069_JPRB,     -0.0072740_JPRB,     -0.0004641_JPRB,  &
&   0.7841240_JPRB,      0.0035747_JPRB,      1.1282387_JPRB,     -0.0000067_JPRB,     -0.0077184_JPRB,     -0.0004727_JPRB,  &
&   0.8119791_JPRB,      0.0033984_JPRB,      1.1260091_JPRB,     -0.0000065_JPRB,     -0.0079879_JPRB,     -0.0004773_JPRB,  &
&   0.8252736_JPRB,      0.0033297_JPRB,      1.1247207_JPRB,     -0.0000064_JPRB,     -0.0080517_JPRB,     -0.0004787_JPRB,  &
&   0.8715187_JPRB,      0.0030628_JPRB,      1.1205369_JPRB,     -0.0000061_JPRB,     -0.0084311_JPRB,     -0.0004853_JPRB,  &
&   0.9141940_JPRB,      0.0027569_JPRB,      1.1118986_JPRB,     -0.0000056_JPRB,     -0.0080947_JPRB,     -0.0004594_JPRB,  &
&   0.9985752_JPRB,      0.0020760_JPRB,      1.0890400_JPRB,     -0.0000042_JPRB,     -0.0066895_JPRB,     -0.0003712_JPRB,  &
&   1.0723894_JPRB,      0.0015504_JPRB,      1.0741393_JPRB,     -0.0000033_JPRB,     -0.0062181_JPRB,     -0.0003297_JPRB,  &
&   1.1060291_JPRB,      0.0012878_JPRB,      1.0652195_JPRB,     -0.0000028_JPRB,     -0.0056551_JPRB,     -0.0002956_JPRB,  &
&   1.1458924_JPRB,      0.0009678_JPRB,      1.0543408_JPRB,     -0.0000022_JPRB,     -0.0048971_JPRB,     -0.0002515_JPRB,  &
&   1.1709108_JPRB,      0.0007889_JPRB,      1.0489937_JPRB,     -0.0000018_JPRB,     -0.0046570_JPRB,     -0.0002346_JPRB,  &
&   1.1807451_JPRB,      0.0007149_JPRB,      1.0465665_JPRB,     -0.0000017_JPRB,     -0.0045099_JPRB,     -0.0002257_JPRB,  &
&   1.1920699_JPRB,      0.0006345_JPRB,      1.0442611_JPRB,     -0.0000016_JPRB,     -0.0044184_JPRB,     -0.0002187_JPRB,  &
&   1.2023804_JPRB,      0.0005550_JPRB,      1.0413097_JPRB,     -0.0000014_JPRB,     -0.0042013_JPRB,     -0.0002068_JPRB,  &
&   1.2068173_JPRB,      0.0005244_JPRB,      1.0399829_JPRB,     -0.0000013_JPRB,     -0.0040735_JPRB,     -0.0002004_JPRB,  &
&   1.0871028_JPRB,      0.0014735_JPRB,      1.0713371_JPRB,     -0.0000032_JPRB,     -0.0060801_JPRB,     -0.0003216_JPRB,  &
&   1.0308711_JPRB,      0.0019264_JPRB,      1.0878648_JPRB,     -0.0000041_JPRB,     -0.0073010_JPRB,     -0.0003904_JPRB,  &
&   0.8530548_JPRB,      0.0032349_JPRB,      1.1288188_JPRB,     -0.0000066_JPRB,     -0.0094329_JPRB,     -0.0005319_JPRB,  &
&   0.6211643_JPRB,      0.0048097_JPRB,      1.1684757_JPRB,     -0.0000092_JPRB,     -0.0102403_JPRB,     -0.0006302_JPRB,  &
&   0.5905747_JPRB,      0.0049762_JPRB,      1.1714398_JPRB,     -0.0000094_JPRB,     -0.0101248_JPRB,     -0.0006293_JPRB,  &
&   0.5954986_JPRB,      0.0048921_JPRB,      1.1637046_JPRB,     -0.0000091_JPRB,     -0.0092340_JPRB,     -0.0005867_JPRB,  &
&   0.3926037_JPRB,      0.0059152_JPRB,      1.1459000_JPRB,     -0.0000098_JPRB,     -0.0026846_JPRB,     -0.0003499_JPRB,  &
&   0.7388054_JPRB,      0.0035636_JPRB,      1.0981411_JPRB,     -0.0000059_JPRB,     -0.0027668_JPRB,     -0.0002626_JPRB,  &
&   0.9036131_JPRB,      0.0023237_JPRB,      1.0580272_JPRB,     -0.0000036_JPRB,     -0.0006267_JPRB,     -0.0001204_JPRB,  &
&   0.7418549_JPRB,      0.0035248_JPRB,      1.0897028_JPRB,     -0.0000059_JPRB,     -0.0018440_JPRB,     -0.0002222_JPRB,  &
&   0.6068466_JPRB,      0.0045453_JPRB,      1.1231864_JPRB,     -0.0000078_JPRB,     -0.0036166_JPRB,     -0.0003398_JPRB,  &
&   0.3479370_JPRB,      0.0062249_JPRB,      1.1525312_JPRB,     -0.0000104_JPRB,     -0.0028074_JPRB,     -0.0003693_JPRB,  &
&   0.2363877_JPRB,      0.0069273_JPRB,      1.1799258_JPRB,     -0.0000116_JPRB,     -0.0043802_JPRB,     -0.0004642_JPRB,  &
&   0.3373092_JPRB,      0.0062878_JPRB,      1.1633609_JPRB,     -0.0000106_JPRB,     -0.0040554_JPRB,     -0.0004262_JPRB,  &
&   0.6247395_JPRB,      0.0043495_JPRB,      1.1159716_JPRB,     -0.0000073_JPRB,     -0.0030484_JPRB,     -0.0003073_JPRB,  &
&   0.9857900_JPRB,      0.0016582_JPRB,      1.0385239_JPRB,     -0.0000024_JPRB,      0.0003630_JPRB,     -0.0000539_JPRB,  &
&   1.2184792_JPRB,      0.0000181_JPRB,      0.9956378_JPRB,      0.0000004_JPRB,      0.0018661_JPRB,      0.0000659_JPRB,  &
&   1.2537888_JPRB,     -0.0004956_JPRB,      0.9677931_JPRB,      0.0000019_JPRB,      0.0048729_JPRB,      0.0002170_JPRB,  &
&   1.2606170_JPRB,     -0.0003948_JPRB,      0.9759904_JPRB,      0.0000013_JPRB,      0.0037645_JPRB,      0.0001559_JPRB,  &
&   1.2545880_JPRB,     -0.0004346_JPRB,      0.9732279_JPRB,      0.0000014_JPRB,      0.0041267_JPRB,      0.0001736_JPRB,  &
&   1.2451640_JPRB,     -0.0004010_JPRB,      0.9734565_JPRB,      0.0000013_JPRB,      0.0041394_JPRB,      0.0001718_JPRB,  &
&   1.2369905_JPRB,     -0.0005564_JPRB,      0.9619827_JPRB,      0.0000020_JPRB,      0.0055948_JPRB,      0.0002458_JPRB,  &
&   1.2300411_JPRB,     -0.0004157_JPRB,      0.9719772_JPRB,      0.0000014_JPRB,      0.0043298_JPRB,      0.0001808_JPRB,  &
&   1.2296224_JPRB,     -0.0005326_JPRB,      0.9697856_JPRB,      0.0000016_JPRB,      0.0043504_JPRB,      0.0001865_JPRB,  &
&   1.2081451_JPRB,     -0.0004750_JPRB,      0.9694291_JPRB,      0.0000015_JPRB,      0.0045307_JPRB,      0.0001917_JPRB,  &
&   1.1881198_JPRB,     -0.0005969_JPRB,      0.9567746_JPRB,      0.0000022_JPRB,      0.0063372_JPRB,      0.0002831_JPRB,  &
&   1.2087283_JPRB,     -0.0005063_JPRB,      0.9714069_JPRB,      0.0000016_JPRB,      0.0041389_JPRB,      0.0001784_JPRB,  &
&   1.5415898_JPRB,     -0.0005267_JPRB,      0.9740522_JPRB,      0.0000016_JPRB,      0.0036936_JPRB,      0.0001619_JPRB,  &
&   1.5390820_JPRB,     -0.0004124_JPRB,      0.9786724_JPRB,      0.0000013_JPRB,      0.0032573_JPRB,      0.0001387_JPRB,  &
&   1.5316032_JPRB,      0.0001143_JPRB,      1.0070270_JPRB,     -0.0000000_JPRB,      0.0002943_JPRB,     -0.0000060_JPRB,  &
&   1.5103142_JPRB,      0.0004699_JPRB,      1.0235202_JPRB,     -0.0000007_JPRB,     -0.0011661_JPRB,     -0.0000782_JPRB,  &
&   1.4419047_JPRB,      0.0010447_JPRB,      1.0419181_JPRB,     -0.0000018_JPRB,     -0.0022534_JPRB,     -0.0001447_JPRB,  &
&   1.2836314_JPRB,      0.0019786_JPRB,      1.0523720_JPRB,     -0.0000029_JPRB,     -0.0008030_JPRB,     -0.0001097_JPRB,  &
&   0.5248775_JPRB,      0.0073975_JPRB,      1.1994574_JPRB,     -0.0000128_JPRB,     -0.0061102_JPRB,     -0.0005585_JPRB,  &
&  -0.6126482_JPRB,      0.0128543_JPRB,      1.3070269_JPRB,     -0.0000198_JPRB,     -0.0022114_JPRB,     -0.0005882_JPRB,  &
&  -0.6596790_JPRB,      0.0126090_JPRB,      1.3168183_JPRB,     -0.0000192_JPRB,     -0.0037281_JPRB,     -0.0006390_JPRB,  &
&  -0.9463256_JPRB,      0.0135645_JPRB,      1.3235052_JPRB,     -0.0000200_JPRB,     -0.0010126_JPRB,     -0.0005541_JPRB,  &
&  -1.1890272_JPRB,      0.0130403_JPRB,      1.3278423_JPRB,     -0.0000180_JPRB,     -0.0013552_JPRB,     -0.0005257_JPRB,  &
&  -0.9529389_JPRB,      0.0135914_JPRB,      1.3243305_JPRB,     -0.0000201_JPRB,     -0.0011483_JPRB,     -0.0005608_JPRB,  &
&  -0.1741631_JPRB,      0.0109464_JPRB,      1.2771302_JPRB,     -0.0000176_JPRB,     -0.0048229_JPRB,     -0.0006336_JPRB,  &
&  -0.1623586_JPRB,      0.0110801_JPRB,      1.2652261_JPRB,     -0.0000178_JPRB,     -0.0031351_JPRB,     -0.0005695_JPRB,  &
&  -0.4812439_JPRB,      0.0120451_JPRB,      1.3032136_JPRB,     -0.0000187_JPRB,     -0.0041525_JPRB,     -0.0006388_JPRB,  &
&  -1.3562232_JPRB,      0.0136408_JPRB,      1.3280472_JPRB,     -0.0000186_JPRB,      0.0007630_JPRB,     -0.0004584_JPRB,  &
&  -1.1265741_JPRB,      0.0129563_JPRB,      1.3275106_JPRB,     -0.0000181_JPRB,     -0.0018238_JPRB,     -0.0005453_JPRB,  &
&  -0.8457010_JPRB,      0.0133315_JPRB,      1.3203005_JPRB,     -0.0000199_JPRB,     -0.0017503_JPRB,     -0.0005779_JPRB,  &
&  -0.9416312_JPRB,      0.0128471_JPRB,      1.3301924_JPRB,     -0.0000186_JPRB,     -0.0035685_JPRB,     -0.0006198_JPRB,  &
&  -2.2295080_JPRB,      0.0142879_JPRB,      1.3460752_JPRB,     -0.0000201_JPRB,     -0.0000279_JPRB,     -0.0005246_JPRB,  &
&  -2.0611153_JPRB,      0.0126394_JPRB,      1.3261472_JPRB,     -0.0000156_JPRB,      0.0000875_JPRB,     -0.0004215_JPRB,  &
&  -2.7155290_JPRB,      0.0119757_JPRB,      1.3178237_JPRB,     -0.0000137_JPRB,      0.0007596_JPRB,     -0.0003607_JPRB,  &
&  -2.7302112_JPRB,      0.0123547_JPRB,      1.3221613_JPRB,     -0.0000147_JPRB,      0.0007120_JPRB,     -0.0003836_JPRB,  &
&  -3.3705804_JPRB,      0.0112225_JPRB,      1.4579241_JPRB,     -0.0000128_JPRB,      0.0171616_JPRB,     -0.0006682_JPRB,  &
&  -3.3705804_JPRB,      0.0112225_JPRB,      1.4579241_JPRB,     -0.0000128_JPRB,      0.0171616_JPRB,     -0.0006682_JPRB,  &
&  -3.6858302_JPRB,      0.0080998_JPRB,      1.7907794_JPRB,     -0.0000099_JPRB,      0.1040133_JPRB,     -0.0009513_JPRB,  &
&  -5.1655874_JPRB,      0.0181943_JPRB,      1.9046609_JPRB,     -0.0000238_JPRB,      0.1657553_JPRB,     -0.0001577_JPRB,  &
&  -7.2007058_JPRB,      0.0255460_JPRB,      1.6274787_JPRB,     -0.0000334_JPRB,      0.2524134_JPRB,      0.0018737_JPRB,  &
&  -7.3275520_JPRB,      0.0156115_JPRB,      1.0423284_JPRB,     -0.0000075_JPRB,      0.2687087_JPRB,      0.0036299_JPRB,  &
&  -6.6708092_JPRB,      0.0065871_JPRB,      0.8313306_JPRB,      0.0000142_JPRB,      0.2618292_JPRB,      0.0041360_JPRB,  &
&  -6.7451741_JPRB,      0.0088835_JPRB,      0.9328906_JPRB,      0.0000094_JPRB,      0.2685995_JPRB,      0.0040371_JPRB,  &
&  -4.5344302_JPRB,      0.0097016_JPRB,      1.9261030_JPRB,     -0.0000359_JPRB,      0.1681990_JPRB,     -0.0022238_JPRB,  &
&  -3.3902128_JPRB,     -0.0005061_JPRB,      1.7828044_JPRB,     -0.0000079_JPRB,      0.1630127_JPRB,     -0.0013619_JPRB/),&
&     SHAPE =(/ n_baran2014_abs, n_baran2014_wn/))

  !> Baran regression coefficients for scattering coef
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_regcoef_sca(n_baran2014_sca, n_baran2014_wn) =  &
  RESHAPE( (/ &
&   1.8818541_JPRB,     -0.0041599_JPRB,      0.9415922_JPRB,      0.0000071_JPRB,     -0.0030161_JPRB,      0.0000420_JPRB,  &
&   1.8680538_JPRB,     -0.0041428_JPRB,      0.9380627_JPRB,      0.0000073_JPRB,     -0.0022187_JPRB,      0.0000765_JPRB,  &
&   1.8638018_JPRB,     -0.0040473_JPRB,      0.9409957_JPRB,      0.0000070_JPRB,     -0.0025653_JPRB,      0.0000572_JPRB,  &
&   1.8419165_JPRB,     -0.0039305_JPRB,      0.9391160_JPRB,      0.0000070_JPRB,     -0.0018473_JPRB,      0.0000834_JPRB,  &
&   1.7433297_JPRB,     -0.0033658_JPRB,      0.9442056_JPRB,      0.0000064_JPRB,     -0.0005144_JPRB,      0.0001206_JPRB,  &
&   1.6672920_JPRB,     -0.0025600_JPRB,      0.9650156_JPRB,      0.0000045_JPRB,     -0.0016400_JPRB,      0.0000306_JPRB,  &
&   1.6439209_JPRB,     -0.0024235_JPRB,      0.9645471_JPRB,      0.0000044_JPRB,     -0.0010647_JPRB,      0.0000494_JPRB,  &
&   1.5899395_JPRB,     -0.0021191_JPRB,      0.9658771_JPRB,      0.0000041_JPRB,     -0.0000392_JPRB,      0.0000810_JPRB,  &
&   1.5394350_JPRB,     -0.0017554_JPRB,      0.9720653_JPRB,      0.0000035_JPRB,      0.0001790_JPRB,      0.0000746_JPRB,  &
&   1.4700943_JPRB,     -0.0012432_JPRB,      0.9826184_JPRB,      0.0000026_JPRB,      0.0002399_JPRB,      0.0000561_JPRB,  &
&   1.4079222_JPRB,     -0.0007311_JPRB,      0.9965876_JPRB,      0.0000016_JPRB,     -0.0003855_JPRB,      0.0000077_JPRB,  &
&   1.3812201_JPRB,     -0.0005057_JPRB,      1.0033551_JPRB,      0.0000012_JPRB,     -0.0007726_JPRB,     -0.0000182_JPRB,  &
&   1.3404293_JPRB,     -0.0001532_JPRB,      1.0147458_JPRB,      0.0000004_JPRB,     -0.0015220_JPRB,     -0.0000648_JPRB,  &
&   1.3233554_JPRB,     -0.0000037_JPRB,      1.0197991_JPRB,      0.0000001_JPRB,     -0.0018796_JPRB,     -0.0000862_JPRB,  &
&   1.3085564_JPRB,      0.0001284_JPRB,      1.0244002_JPRB,     -0.0000002_JPRB,     -0.0022202_JPRB,     -0.0001062_JPRB,  &
&   1.2783607_JPRB,      0.0003955_JPRB,      1.0340782_JPRB,     -0.0000008_JPRB,     -0.0029718_JPRB,     -0.0001490_JPRB,  &
&   1.2648875_JPRB,      0.0005167_JPRB,      1.0387843_JPRB,     -0.0000010_JPRB,     -0.0033649_JPRB,     -0.0001706_JPRB,  &
&   1.2404966_JPRB,      0.0007380_JPRB,      1.0478185_JPRB,     -0.0000016_JPRB,     -0.0041580_JPRB,     -0.0002134_JPRB,  &
&   1.2142440_JPRB,      0.0009671_JPRB,      1.0573574_JPRB,     -0.0000021_JPRB,     -0.0050078_JPRB,     -0.0002586_JPRB,  &
&   1.1840750_JPRB,      0.0012256_JPRB,      1.0682009_JPRB,     -0.0000027_JPRB,     -0.0059755_JPRB,     -0.0003100_JPRB,  &
&   1.1504016_JPRB,      0.0015060_JPRB,      1.0801098_JPRB,     -0.0000033_JPRB,     -0.0070453_JPRB,     -0.0003665_JPRB,  &
&   1.1070281_JPRB,      0.0018326_JPRB,      1.0934160_JPRB,     -0.0000040_JPRB,     -0.0081684_JPRB,     -0.0004260_JPRB,  &
&   1.0011053_JPRB,      0.0026802_JPRB,      1.1281559_JPRB,     -0.0000059_JPRB,     -0.0111146_JPRB,     -0.0005844_JPRB,  &
&   0.9238229_JPRB,      0.0033157_JPRB,      1.1569966_JPRB,     -0.0000074_JPRB,     -0.0138207_JPRB,     -0.0007240_JPRB,  &
&   1.0094792_JPRB,      0.0026989_JPRB,      1.1443410_JPRB,     -0.0000065_JPRB,     -0.0139462_JPRB,     -0.0007040_JPRB,  &
&   1.3133691_JPRB,      0.0004921_JPRB,      1.0853174_JPRB,     -0.0000025_JPRB,     -0.0117837_JPRB,     -0.0005276_JPRB,  &
&   1.4454701_JPRB,     -0.0004861_JPRB,      1.0576432_JPRB,     -0.0000007_JPRB,     -0.0105202_JPRB,     -0.0004372_JPRB,  &
&   1.6301569_JPRB,     -0.0019170_JPRB,      1.0145912_JPRB,      0.0000020_JPRB,     -0.0081969_JPRB,     -0.0002821_JPRB,  &
&   1.7167589_JPRB,     -0.0026629_JPRB,      0.9882475_JPRB,      0.0000036_JPRB,     -0.0062827_JPRB,     -0.0001688_JPRB,  &
&   1.7996461_JPRB,     -0.0033832_JPRB,      0.9565990_JPRB,      0.0000053_JPRB,     -0.0033832_JPRB,     -0.0000183_JPRB,  &
&   1.8123924_JPRB,     -0.0034643_JPRB,      0.9529447_JPRB,      0.0000055_JPRB,     -0.0030745_JPRB,     -0.0000033_JPRB,  &
&   1.7858787_JPRB,     -0.0033490_JPRB,      0.9460804_JPRB,      0.0000055_JPRB,     -0.0015365_JPRB,      0.0000579_JPRB,  &
&   1.7761738_JPRB,     -0.0033387_JPRB,      0.9412309_JPRB,      0.0000057_JPRB,     -0.0006497_JPRB,      0.0000957_JPRB,  &
&   1.7732545_JPRB,     -0.0033596_JPRB,      0.9381641_JPRB,      0.0000058_JPRB,     -0.0001682_JPRB,      0.0001178_JPRB,  &
&   1.7649243_JPRB,     -0.0034103_JPRB,      0.9316873_JPRB,      0.0000062_JPRB,      0.0009132_JPRB,      0.0001678_JPRB,  &
&   1.7477012_JPRB,     -0.0033427_JPRB,      0.9293531_JPRB,      0.0000062_JPRB,      0.0016109_JPRB,      0.0001954_JPRB,  &
&   1.6975242_JPRB,     -0.0030183_JPRB,      0.9329759_JPRB,      0.0000058_JPRB,      0.0022128_JPRB,      0.0002073_JPRB,  &
&   1.6542213_JPRB,     -0.0027785_JPRB,      0.9351838_JPRB,      0.0000056_JPRB,      0.0028532_JPRB,      0.0002259_JPRB,  &
&   1.6273148_JPRB,     -0.0025899_JPRB,      0.9381645_JPRB,      0.0000053_JPRB,      0.0030084_JPRB,      0.0002246_JPRB,  &
&   1.5893330_JPRB,     -0.0023022_JPRB,      0.9438272_JPRB,      0.0000047_JPRB,      0.0029963_JPRB,      0.0002118_JPRB,  &
&   1.5646104_JPRB,     -0.0021335_JPRB,      0.9464268_JPRB,      0.0000045_JPRB,      0.0031599_JPRB,      0.0002117_JPRB,  &
&   1.5546014_JPRB,     -0.0020611_JPRB,      0.9479274_JPRB,      0.0000044_JPRB,      0.0031584_JPRB,      0.0002086_JPRB,  &
&   1.5438324_JPRB,     -0.0019873_JPRB,      0.9493487_JPRB,      0.0000042_JPRB,      0.0031882_JPRB,      0.0002068_JPRB,  &
&   1.5328705_JPRB,     -0.0019042_JPRB,      0.9515911_JPRB,      0.0000041_JPRB,      0.0030986_JPRB,      0.0001996_JPRB,  &
&   1.5254335_JPRB,     -0.0018397_JPRB,      0.9544240_JPRB,      0.0000039_JPRB,      0.0028318_JPRB,      0.0001856_JPRB,  &
&   1.6213116_JPRB,     -0.0025424_JPRB,      0.9370202_JPRB,      0.0000052_JPRB,      0.0032927_JPRB,      0.0002326_JPRB,  &
&   1.6599189_JPRB,     -0.0028173_JPRB,      0.9295779_JPRB,      0.0000056_JPRB,      0.0035620_JPRB,      0.0002541_JPRB,  &
&   1.7433066_JPRB,     -0.0032863_JPRB,      0.9198977_JPRB,      0.0000062_JPRB,      0.0032823_JPRB,      0.0002564_JPRB,  &
&   1.7861375_JPRB,     -0.0033174_JPRB,      0.9224022_JPRB,      0.0000057_JPRB,      0.0022975_JPRB,      0.0002069_JPRB,  &
&   1.7863568_JPRB,     -0.0032111_JPRB,      0.9261766_JPRB,      0.0000053_JPRB,      0.0018502_JPRB,      0.0001793_JPRB,  &
&   1.7679735_JPRB,     -0.0029645_JPRB,      0.9319047_JPRB,      0.0000046_JPRB,      0.0015318_JPRB,      0.0001500_JPRB,  &
&   1.7137553_JPRB,     -0.0021771_JPRB,      0.9583729_JPRB,      0.0000025_JPRB,     -0.0007145_JPRB,      0.0000113_JPRB,  &
&   1.6676614_JPRB,     -0.0022333_JPRB,      0.9480620_JPRB,      0.0000034_JPRB,      0.0013992_JPRB,      0.0001142_JPRB,  &
&   1.5769590_JPRB,     -0.0016569_JPRB,      0.9606525_JPRB,      0.0000025_JPRB,      0.0014962_JPRB,      0.0000961_JPRB,  &
&   1.6372755_JPRB,     -0.0019943_JPRB,      0.9536987_JPRB,      0.0000030_JPRB,      0.0013777_JPRB,      0.0001020_JPRB,  &
&   1.6844155_JPRB,     -0.0022772_JPRB,      0.9438073_JPRB,      0.0000034_JPRB,      0.0017484_JPRB,      0.0001271_JPRB,  &
&   1.7352614_JPRB,     -0.0023683_JPRB,      0.9457099_JPRB,      0.0000031_JPRB,      0.0007353_JPRB,      0.0000802_JPRB,  &
&   1.7491272_JPRB,     -0.0023441_JPRB,      0.9449396_JPRB,      0.0000029_JPRB,      0.0006567_JPRB,      0.0000753_JPRB,  &
&   1.7422418_JPRB,     -0.0024019_JPRB,      0.9443332_JPRB,      0.0000032_JPRB,      0.0007740_JPRB,      0.0000856_JPRB,  &
&   1.6934469_JPRB,     -0.0023218_JPRB,      0.9484240_JPRB,      0.0000034_JPRB,      0.0009965_JPRB,      0.0000987_JPRB,  &
&   1.5364575_JPRB,     -0.0013298_JPRB,      0.9740401_JPRB,      0.0000019_JPRB,      0.0006515_JPRB,      0.0000465_JPRB,  &
&   1.4008435_JPRB,     -0.0004886_JPRB,      0.9890889_JPRB,      0.0000009_JPRB,      0.0012733_JPRB,      0.0000461_JPRB,  &
&   1.3775735_JPRB,     -0.0001785_JPRB,      1.0046573_JPRB,      0.0000000_JPRB,     -0.0003239_JPRB,     -0.0000354_JPRB,  &
&   1.3729738_JPRB,     -0.0002326_JPRB,      1.0010176_JPRB,      0.0000004_JPRB,      0.0001603_JPRB,     -0.0000050_JPRB,  &
&   1.3790951_JPRB,     -0.0002476_JPRB,      1.0036706_JPRB,      0.0000004_JPRB,     -0.0003064_JPRB,     -0.0000209_JPRB,  &
&   1.3824277_JPRB,     -0.0001966_JPRB,      1.0073774_JPRB,      0.0000002_JPRB,     -0.0008057_JPRB,     -0.0000448_JPRB,  &
&   1.3899965_JPRB,     -0.0001110_JPRB,      1.0140623_JPRB,     -0.0000001_JPRB,     -0.0016356_JPRB,     -0.0000876_JPRB,  &
&   1.3910298_JPRB,     -0.0001603_JPRB,      1.0113780_JPRB,      0.0000001_JPRB,     -0.0013585_JPRB,     -0.0000686_JPRB,  &
&   1.3970970_JPRB,     -0.0001248_JPRB,      1.0139113_JPRB,      0.0000000_JPRB,     -0.0016751_JPRB,     -0.0000827_JPRB,  &
&   1.4080128_JPRB,     -0.0001086_JPRB,      1.0175929_JPRB,     -0.0000001_JPRB,     -0.0022219_JPRB,     -0.0001065_JPRB,  &
&   1.4216770_JPRB,     -0.0000638_JPRB,      1.0270341_JPRB,     -0.0000005_JPRB,     -0.0036585_JPRB,     -0.0001728_JPRB,  &
&   1.4097853_JPRB,     -0.0000877_JPRB,      1.0243308_JPRB,     -0.0000003_JPRB,     -0.0032341_JPRB,     -0.0001490_JPRB,  &
&   1.7188645_JPRB,     -0.0000018_JPRB,      1.0277355_JPRB,     -0.0000005_JPRB,     -0.0035719_JPRB,     -0.0001660_JPRB,  &
&   1.7227050_JPRB,     -0.0000605_JPRB,      1.0296464_JPRB,     -0.0000004_JPRB,     -0.0040334_JPRB,     -0.0001833_JPRB,  &
&   1.7081963_JPRB,     -0.0000792_JPRB,      1.0461830_JPRB,     -0.0000008_JPRB,     -0.0068859_JPRB,     -0.0003018_JPRB,  &
&   1.7162700_JPRB,     -0.0001368_JPRB,      1.0600086_JPRB,     -0.0000011_JPRB,     -0.0094018_JPRB,     -0.0004071_JPRB,  &
&   1.7581002_JPRB,     -0.0004481_JPRB,      1.0549202_JPRB,     -0.0000007_JPRB,     -0.0096977_JPRB,     -0.0004096_JPRB,  &
&   1.8725071_JPRB,     -0.0011695_JPRB,      1.0340371_JPRB,      0.0000004_JPRB,     -0.0088661_JPRB,     -0.0003538_JPRB,  &
&   2.1169651_JPRB,     -0.0026713_JPRB,      0.9588926_JPRB,      0.0000031_JPRB,     -0.0027598_JPRB,     -0.0000481_JPRB,  &
&   1.9439953_JPRB,     -0.0002499_JPRB,      1.0024250_JPRB,     -0.0000015_JPRB,     -0.0025176_JPRB,     -0.0001510_JPRB,  &
&   1.9479560_JPRB,     -0.0003114_JPRB,      0.9922268_JPRB,     -0.0000010_JPRB,     -0.0008146_JPRB,     -0.0000715_JPRB,  &
&   1.9383753_JPRB,     -0.0001792_JPRB,      0.9971319_JPRB,     -0.0000009_JPRB,     -0.0007706_JPRB,     -0.0000694_JPRB,  &
&   1.9300413_JPRB,     -0.0001027_JPRB,      1.0000081_JPRB,     -0.0000005_JPRB,     -0.0003337_JPRB,     -0.0000436_JPRB,  &
&   1.9317776_JPRB,     -0.0000795_JPRB,      1.0049350_JPRB,     -0.0000012_JPRB,     -0.0016893_JPRB,     -0.0001128_JPRB,  &
&   1.9840600_JPRB,     -0.0007744_JPRB,      0.9960080_JPRB,     -0.0000009_JPRB,     -0.0032416_JPRB,     -0.0001661_JPRB,  &
&   1.9923679_JPRB,     -0.0008690_JPRB,      0.9960973_JPRB,     -0.0000008_JPRB,     -0.0035914_JPRB,     -0.0001794_JPRB,  &
&   1.9540855_JPRB,     -0.0003524_JPRB,      1.0039520_JPRB,     -0.0000013_JPRB,     -0.0029138_JPRB,     -0.0001640_JPRB,  &
&   1.9205800_JPRB,      0.0000162_JPRB,      1.0068952_JPRB,     -0.0000008_JPRB,     -0.0009012_JPRB,     -0.0000732_JPRB,  &
&   1.9221174_JPRB,     -0.0000044_JPRB,      1.0041683_JPRB,     -0.0000009_JPRB,     -0.0007331_JPRB,     -0.0000696_JPRB,  &
&   1.9308059_JPRB,     -0.0001220_JPRB,      0.9984626_JPRB,     -0.0000012_JPRB,     -0.0008392_JPRB,     -0.0000813_JPRB,  &
&   1.9227374_JPRB,     -0.0000628_JPRB,      0.9945846_JPRB,     -0.0000009_JPRB,      0.0003135_JPRB,     -0.0000295_JPRB,  &
&   1.9207764_JPRB,     -0.0000692_JPRB,      0.9971474_JPRB,      0.0000001_JPRB,      0.0011919_JPRB,      0.0000274_JPRB,  &
&   1.9228655_JPRB,     -0.0000766_JPRB,      0.9980146_JPRB,      0.0000001_JPRB,      0.0009863_JPRB,      0.0000189_JPRB,  &
&   1.9319186_JPRB,     -0.0001731_JPRB,      0.9970861_JPRB,      0.0000004_JPRB,      0.0010026_JPRB,      0.0000272_JPRB,  &
&   1.9356718_JPRB,     -0.0001913_JPRB,      0.9989667_JPRB,      0.0000004_JPRB,      0.0005884_JPRB,      0.0000117_JPRB,  &
&   1.9404902_JPRB,     -0.0002266_JPRB,      1.0010403_JPRB,      0.0000005_JPRB,      0.0001631_JPRB,     -0.0000020_JPRB,  &
&   1.9404902_JPRB,     -0.0002266_JPRB,      1.0010403_JPRB,      0.0000005_JPRB,      0.0001631_JPRB,     -0.0000020_JPRB,  &
&   1.9368251_JPRB,     -0.0001914_JPRB,      1.0016542_JPRB,      0.0000004_JPRB,      0.0001607_JPRB,     -0.0000041_JPRB,  &
&   1.9372079_JPRB,     -0.0001973_JPRB,      1.0015487_JPRB,      0.0000004_JPRB,      0.0001696_JPRB,     -0.0000035_JPRB,  &
&   1.9371583_JPRB,     -0.0001895_JPRB,      1.0020005_JPRB,      0.0000003_JPRB,      0.0000949_JPRB,     -0.0000073_JPRB,  &
&   1.8353614_JPRB,      0.0009690_JPRB,      1.0219334_JPRB,     -0.0000030_JPRB,     -0.0013068_JPRB,     -0.0001376_JPRB,  &
&   1.9365025_JPRB,     -0.0001836_JPRB,      1.0018747_JPRB,      0.0000003_JPRB,      0.0001416_JPRB,     -0.0000054_JPRB,  &
&   1.9386098_JPRB,     -0.0002090_JPRB,      1.0013428_JPRB,      0.0000004_JPRB,      0.0001698_JPRB,     -0.0000028_JPRB,  &
&   1.9399405_JPRB,     -0.0002210_JPRB,      1.0010468_JPRB,      0.0000004_JPRB,      0.0001833_JPRB,     -0.0000016_JPRB,  &
&   1.9374946_JPRB,     -0.0002039_JPRB,      1.0010631_JPRB,      0.0000004_JPRB,      0.0002361_JPRB,     -0.0000006_JPRB/),&
&     SHAPE =(/ n_baran2014_sca, n_baran2014_wn/))

  !> Baran regression coefficients for backscattering parameter (bpr)
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_regcoef_bpr(n_baran2014_bpr, n_baran2014_wn) = &
  RESHAPE( (/ &
&        0.1587988_JPRB,     -0.0005240_JPRB,     -0.0201070_JPRB,  &
&        0.1561375_JPRB,     -0.0005188_JPRB,     -0.0202848_JPRB,  &
&        0.1531134_JPRB,     -0.0005048_JPRB,     -0.0199168_JPRB,  &
&        0.1535229_JPRB,     -0.0005054_JPRB,     -0.0199057_JPRB,  &
&        0.1385066_JPRB,     -0.0004520_JPRB,     -0.0189136_JPRB,  &
&        0.1308932_JPRB,     -0.0004102_JPRB,     -0.0172828_JPRB,  &
&        0.1275260_JPRB,     -0.0003955_JPRB,     -0.0168293_JPRB,  &
&        0.1226156_JPRB,     -0.0003747_JPRB,     -0.0163902_JPRB,  &
&        0.1175362_JPRB,     -0.0003540_JPRB,     -0.0158053_JPRB,  &
&        0.1091534_JPRB,     -0.0003063_JPRB,     -0.0143611_JPRB,  &
&        0.1016214_JPRB,     -0.0002658_JPRB,     -0.0129283_JPRB,  &
&        0.0986325_JPRB,     -0.0002495_JPRB,     -0.0122750_JPRB,  &
&        0.0942434_JPRB,     -0.0002261_JPRB,     -0.0112688_JPRB,  &
&        0.0924031_JPRB,     -0.0002167_JPRB,     -0.0108487_JPRB,  &
&        0.0909568_JPRB,     -0.0002092_JPRB,     -0.0104969_JPRB,  &
&        0.0890206_JPRB,     -0.0002003_JPRB,     -0.0100345_JPRB,  &
&        0.0875863_JPRB,     -0.0001947_JPRB,     -0.0097526_JPRB,  &
&        0.0839582_JPRB,     -0.0001816_JPRB,     -0.0091181_JPRB,  &
&        0.0807898_JPRB,     -0.0001747_JPRB,     -0.0087135_JPRB,  &
&        0.0773499_JPRB,     -0.0001685_JPRB,     -0.0083142_JPRB,  &
&        0.0736146_JPRB,     -0.0001634_JPRB,     -0.0079223_JPRB,  &
&        0.0705723_JPRB,     -0.0001586_JPRB,     -0.0073824_JPRB,  &
&        0.0640328_JPRB,     -0.0001511_JPRB,     -0.0065295_JPRB,  &
&        0.0576769_JPRB,     -0.0001468_JPRB,     -0.0060954_JPRB,  &
&        0.0496391_JPRB,     -0.0001455_JPRB,     -0.0066496_JPRB,  &
&        0.0555103_JPRB,     -0.0001779_JPRB,     -0.0075017_JPRB,  &
&        0.0579754_JPRB,     -0.0001861_JPRB,     -0.0075532_JPRB,  &
&        0.0647925_JPRB,     -0.0002062_JPRB,     -0.0078311_JPRB,  &
&        0.0690378_JPRB,     -0.0002156_JPRB,     -0.0079583_JPRB,  &
&        0.0769242_JPRB,     -0.0002373_JPRB,     -0.0087152_JPRB,  &
&        0.0784279_JPRB,     -0.0002422_JPRB,     -0.0089660_JPRB,  &
&        0.0823682_JPRB,     -0.0002573_JPRB,     -0.0096876_JPRB,  &
&        0.0844680_JPRB,     -0.0002658_JPRB,     -0.0100556_JPRB,  &
&        0.0845843_JPRB,     -0.0002677_JPRB,     -0.0102534_JPRB,  &
&        0.0860361_JPRB,     -0.0002732_JPRB,     -0.0105088_JPRB,  &
&        0.0847631_JPRB,     -0.0002702_JPRB,     -0.0106223_JPRB,  &
&        0.0813323_JPRB,     -0.0002600_JPRB,     -0.0106050_JPRB,  &
&        0.0775648_JPRB,     -0.0002491_JPRB,     -0.0105942_JPRB,  &
&        0.0740292_JPRB,     -0.0002348_JPRB,     -0.0101513_JPRB,  &
&        0.0687879_JPRB,     -0.0002135_JPRB,     -0.0094718_JPRB,  &
&        0.0659706_JPRB,     -0.0002018_JPRB,     -0.0090406_JPRB,  &
&        0.0644756_JPRB,     -0.0001957_JPRB,     -0.0088306_JPRB,  &
&        0.0635377_JPRB,     -0.0001914_JPRB,     -0.0086414_JPRB,  &
&        0.0607576_JPRB,     -0.0001810_JPRB,     -0.0083236_JPRB,  &
&        0.0573257_JPRB,     -0.0001689_JPRB,     -0.0077697_JPRB,  &
&        0.0669622_JPRB,     -0.0002121_JPRB,     -0.0089765_JPRB,  &
&        0.0736715_JPRB,     -0.0002384_JPRB,     -0.0097332_JPRB,  &
&        0.0910080_JPRB,     -0.0003001_JPRB,     -0.0114368_JPRB,  &
&        0.1109842_JPRB,     -0.0003621_JPRB,     -0.0130906_JPRB,  &
&        0.1134381_JPRB,     -0.0003690_JPRB,     -0.0133234_JPRB,  &
&        0.1156123_JPRB,     -0.0003824_JPRB,     -0.0142937_JPRB,  &
&        0.1411101_JPRB,     -0.0004478_JPRB,     -0.0152190_JPRB,  &
&        0.1183217_JPRB,     -0.0003849_JPRB,     -0.0143075_JPRB,  &
&        0.0990684_JPRB,     -0.0003013_JPRB,     -0.0111292_JPRB,  &
&        0.1115547_JPRB,     -0.0003487_JPRB,     -0.0127669_JPRB,  &
&        0.1248343_JPRB,     -0.0004042_JPRB,     -0.0146931_JPRB,  &
&        0.1486285_JPRB,     -0.0004693_JPRB,     -0.0160057_JPRB,  &
&        0.1624163_JPRB,     -0.0005122_JPRB,     -0.0174479_JPRB,  &
&        0.1598173_JPRB,     -0.0005125_JPRB,     -0.0182308_JPRB,  &
&        0.1380756_JPRB,     -0.0004518_JPRB,     -0.0176440_JPRB,  &
&        0.1018242_JPRB,     -0.0003024_JPRB,     -0.0131672_JPRB,  &
&        0.0720719_JPRB,     -0.0001581_JPRB,     -0.0074581_JPRB,  &
&        0.0771788_JPRB,     -0.0001214_JPRB,     -0.0035313_JPRB,  &
&        0.0715713_JPRB,     -0.0000944_JPRB,     -0.0035499_JPRB,  &
&        0.0767097_JPRB,     -0.0000877_JPRB,     -0.0030490_JPRB,  &
&        0.0803117_JPRB,     -0.0000821_JPRB,     -0.0027825_JPRB,  &
&        0.0915042_JPRB,     -0.0001017_JPRB,     -0.0022817_JPRB,  &
&        0.0886400_JPRB,     -0.0000782_JPRB,     -0.0023010_JPRB,  &
&        0.0939796_JPRB,     -0.0000673_JPRB,     -0.0017332_JPRB,  &
&        0.0984249_JPRB,     -0.0000648_JPRB,     -0.0014554_JPRB,  &
&        0.0957513_JPRB,     -0.0000680_JPRB,     -0.0013343_JPRB,  &
&        0.0867182_JPRB,     -0.0000555_JPRB,     -0.0010976_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB/),&
&     SHAPE =(/ n_baran2014_bpr, n_baran2014_wn/))

  !> Baran regression coefficients for asymmetry parameter
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2014_regcoef_asym(n_baran2014_asym, n_baran2014_wn) = &
  RESHAPE( (/ &
&        0.7355958_JPRB,      0.0009182_JPRB,      0.0347969_JPRB,  &
&        0.7402210_JPRB,      0.0009095_JPRB,      0.0351265_JPRB,  &
&        0.7454476_JPRB,      0.0008854_JPRB,      0.0345097_JPRB,  &
&        0.7447460_JPRB,      0.0008864_JPRB,      0.0344883_JPRB,  &
&        0.7709712_JPRB,      0.0007945_JPRB,      0.0329041_JPRB,  &
&        0.7842521_JPRB,      0.0007222_JPRB,      0.0301405_JPRB,  &
&        0.7901911_JPRB,      0.0006966_JPRB,      0.0293821_JPRB,  &
&        0.7988284_JPRB,      0.0006602_JPRB,      0.0286462_JPRB,  &
&        0.8078339_JPRB,      0.0006240_JPRB,      0.0276640_JPRB,  &
&        0.8224811_JPRB,      0.0005410_JPRB,      0.0251832_JPRB,  &
&        0.8358004_JPRB,      0.0004700_JPRB,      0.0227262_JPRB,  &
&        0.8411079_JPRB,      0.0004413_JPRB,      0.0216033_JPRB,  &
&        0.8489682_JPRB,      0.0003999_JPRB,      0.0198720_JPRB,  &
&        0.8522904_JPRB,      0.0003832_JPRB,      0.0191478_JPRB,  &
&        0.8548987_JPRB,      0.0003697_JPRB,      0.0185397_JPRB,  &
&        0.8584062_JPRB,      0.0003539_JPRB,      0.0177371_JPRB,  &
&        0.8610385_JPRB,      0.0003436_JPRB,      0.0172470_JPRB,  &
&        0.8676360_JPRB,      0.0003195_JPRB,      0.0161310_JPRB,  &
&        0.8734733_JPRB,      0.0003060_JPRB,      0.0153989_JPRB,  &
&        0.8797387_JPRB,      0.0002935_JPRB,      0.0146516_JPRB,  &
&        0.8864488_JPRB,      0.0002831_JPRB,      0.0138944_JPRB,  &
&        0.8919155_JPRB,      0.0002731_JPRB,      0.0128752_JPRB,  &
&        0.9038114_JPRB,      0.0002556_JPRB,      0.0112225_JPRB,  &
&        0.9156259_JPRB,      0.0002411_JPRB,      0.0102551_JPRB,  &
&        0.9304165_JPRB,      0.0002282_JPRB,      0.0108593_JPRB,  &
&        0.9213451_JPRB,      0.0002784_JPRB,      0.0122520_JPRB,  &
&        0.9172354_JPRB,      0.0002925_JPRB,      0.0123699_JPRB,  &
&        0.9053992_JPRB,      0.0003302_JPRB,      0.0129873_JPRB,  &
&        0.8976548_JPRB,      0.0003503_JPRB,      0.0133280_JPRB,  &
&        0.8832493_JPRB,      0.0003943_JPRB,      0.0148327_JPRB,  &
&        0.8804979_JPRB,      0.0004039_JPRB,      0.0153049_JPRB,  &
&        0.8734266_JPRB,      0.0004322_JPRB,      0.0166424_JPRB,  &
&        0.8696879_JPRB,      0.0004479_JPRB,      0.0173269_JPRB,  &
&        0.8694825_JPRB,      0.0004513_JPRB,      0.0176819_JPRB,  &
&        0.8668537_JPRB,      0.0004617_JPRB,      0.0181623_JPRB,  &
&        0.8690679_JPRB,      0.0004563_JPRB,      0.0183531_JPRB,  &
&        0.8751014_JPRB,      0.0004378_JPRB,      0.0182854_JPRB,  &
&        0.8817230_JPRB,      0.0004178_JPRB,      0.0182207_JPRB,  &
&        0.8878642_JPRB,      0.0003924_JPRB,      0.0174023_JPRB,  &
&        0.8969418_JPRB,      0.0003546_JPRB,      0.0161523_JPRB,  &
&        0.9018132_JPRB,      0.0003337_JPRB,      0.0153642_JPRB,  &
&        0.9043907_JPRB,      0.0003230_JPRB,      0.0149789_JPRB,  &
&        0.9060041_JPRB,      0.0003154_JPRB,      0.0146366_JPRB,  &
&        0.9107886_JPRB,      0.0002969_JPRB,      0.0140457_JPRB,  &
&        0.9168034_JPRB,      0.0002743_JPRB,      0.0130070_JPRB,  &
&        0.9007108_JPRB,      0.0003473_JPRB,      0.0151445_JPRB,  &
&        0.8891233_JPRB,      0.0003940_JPRB,      0.0165467_JPRB,  &
&        0.8584235_JPRB,      0.0005075_JPRB,      0.0198056_JPRB,  &
&        0.8219616_JPRB,      0.0006258_JPRB,      0.0229466_JPRB,  &
&        0.8174221_JPRB,      0.0006393_JPRB,      0.0233732_JPRB,  &
&        0.8134427_JPRB,      0.0006635_JPRB,      0.0250704_JPRB,  &
&        0.7668604_JPRB,      0.0007863_JPRB,      0.0266353_JPRB,  &
&        0.8081666_JPRB,      0.0006706_JPRB,      0.0251204_JPRB,  &
&        0.8426998_JPRB,      0.0005203_JPRB,      0.0195128_JPRB,  &
&        0.8200990_JPRB,      0.0006072_JPRB,      0.0224451_JPRB,  &
&        0.7962832_JPRB,      0.0007066_JPRB,      0.0257899_JPRB,  &
&        0.7534397_JPRB,      0.0008244_JPRB,      0.0279224_JPRB,  &
&        0.7294109_JPRB,      0.0008976_JPRB,      0.0302464_JPRB,  &
&        0.7338828_JPRB,      0.0008983_JPRB,      0.0316033_JPRB,  &
&        0.7720130_JPRB,      0.0007934_JPRB,      0.0307749_JPRB,  &
&        0.8366359_JPRB,      0.0005288_JPRB,      0.0231502_JPRB,  &
&        0.8892020_JPRB,      0.0002733_JPRB,      0.0130474_JPRB,  &
&        0.8800176_JPRB,      0.0002108_JPRB,      0.0061699_JPRB,  &
&        0.8897492_JPRB,      0.0001641_JPRB,      0.0062252_JPRB,  &
&        0.8801830_JPRB,      0.0001562_JPRB,      0.0055227_JPRB,  &
&        0.8727148_JPRB,      0.0001500_JPRB,      0.0049954_JPRB,  &
&        0.8536847_JPRB,      0.0001802_JPRB,      0.0040333_JPRB,  &
&        0.8589215_JPRB,      0.0001376_JPRB,      0.0040478_JPRB,  &
&        0.8496447_JPRB,      0.0001180_JPRB,      0.0030349_JPRB,  &
&        0.8419617_JPRB,      0.0001131_JPRB,      0.0025385_JPRB,  &
&        0.8465603_JPRB,      0.0001191_JPRB,      0.0023360_JPRB,  &
&        0.8623170_JPRB,      0.0000977_JPRB,      0.0019314_JPRB,  &
&        0.8778459_JPRB,      0.0000927_JPRB,      0.0018021_JPRB,  &
&        0.8905257_JPRB,      0.0000948_JPRB,      0.0020659_JPRB,  &
&        0.9410098_JPRB,      0.0001140_JPRB,      0.0034609_JPRB,  &
&        0.9525716_JPRB,      0.0001402_JPRB,      0.0045444_JPRB,  &
&        0.9520232_JPRB,      0.0001632_JPRB,      0.0052411_JPRB,  &
&        0.9347847_JPRB,      0.0002116_JPRB,      0.0055922_JPRB,  &
&        0.8746641_JPRB,      0.0003816_JPRB,      0.0091081_JPRB,  &
&        0.8044567_JPRB,      0.0004355_JPRB,      0.0101626_JPRB,  &
&        0.7900056_JPRB,      0.0004257_JPRB,      0.0108394_JPRB,  &
&        0.7701907_JPRB,      0.0004193_JPRB,      0.0111116_JPRB,  &
&        0.7820739_JPRB,      0.0002936_JPRB,      0.0087696_JPRB,  &
&        0.7568061_JPRB,      0.0004511_JPRB,      0.0133549_JPRB,  &
&        0.7562644_JPRB,      0.0006703_JPRB,      0.0212950_JPRB,  &
&        0.7468803_JPRB,      0.0007232_JPRB,      0.0228591_JPRB,  &
&        0.7507063_JPRB,      0.0005909_JPRB,      0.0190169_JPRB,  &
&        0.7562378_JPRB,      0.0003511_JPRB,      0.0117171_JPRB,  &
&        0.7622226_JPRB,      0.0003414_JPRB,      0.0118827_JPRB,  &
&        0.7400044_JPRB,      0.0005108_JPRB,      0.0156280_JPRB,  &
&        0.7530717_JPRB,      0.0003983_JPRB,      0.0124300_JPRB,  &
&        0.7676701_JPRB,      0.0001860_JPRB,      0.0072189_JPRB,  &
&        0.7752351_JPRB,      0.0001563_JPRB,      0.0066437_JPRB,  &
&        0.7750628_JPRB,      0.0001456_JPRB,      0.0068096_JPRB,  &
&        0.7758680_JPRB,      0.0001373_JPRB,      0.0065790_JPRB,  &
&        0.7729453_JPRB,      0.0001434_JPRB,      0.0071777_JPRB,  &
&        0.7729453_JPRB,      0.0001434_JPRB,      0.0071777_JPRB,  &
&        0.7732092_JPRB,      0.0001333_JPRB,      0.0068154_JPRB,  &
&        0.7717055_JPRB,      0.0001287_JPRB,      0.0066530_JPRB,  &
&        0.7696181_JPRB,      0.0001293_JPRB,      0.0066801_JPRB,  &
&        0.7681362_JPRB,      0.0001270_JPRB,      0.0064771_JPRB,  &
&        0.7645441_JPRB,      0.0001235_JPRB,      0.0064520_JPRB,  &
&        0.7550029_JPRB,      0.0001242_JPRB,      0.0066489_JPRB,  &
&        0.7446464_JPRB,      0.0001175_JPRB,      0.0064077_JPRB,  &
&        0.7322924_JPRB,      0.0001154_JPRB,      0.0061708_JPRB/),&
&     SHAPE =(/ n_baran2014_asym, n_baran2014_wn/))

END MODULE mod_rttov_baran2014_icldata

