! Description:
!> @file
!!   Contains data for the Baran 2018 ice optical property parameterisation
!
!> @brief
!!   Contains data for the Baran 2018 ice optical property parameterisation
!
! Copyright:
!    This software was developed within the context of
!    the EUMETSAT Satellite Application Facility on
!    Numerical Weather Prediction (NWP SAF), under the
!    Cooperation Agreement dated 7 December 2016, between
!    EUMETSAT and the Met Office, UK, by one or more partners
!    within the NWP SAF. The partners in the NWP SAF are
!    the Met Office, ECMWF, DWD and MeteoFrance.
!
!    Copyright 2019, EUMETSAT, All Rights Reserved.
!
MODULE mod_rttov_baran2018_icldata

  USE parkind1, ONLY : jprb, jpim
  IMPLICIT NONE

  PRIVATE

  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_max_asym = 1._JPRB - 1.E-6_JPRB !< Maximum allowed asym value

  ! Baran database training limits
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_iwc_min  = 6.0000001e-06_JPRB  !< IWC minimum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_iwc_max  = 1.969466_JPRB       !< IWC maximum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_temp_min = 193.157_JPRB        !< Temperature minimum
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_temp_max = 273.12701_JPRB      !< Temperature maximum
 
  ! Baran database dimensions
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2018_wn   = 145_JPIM !< Number of wavenumbers
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2018_abs  =   6_JPIM !< Number of coefs for abs parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2018_sca  =   6_JPIM !< Number of coefs for sca parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2018_bpr  =   3_JPIM !< Number of coefs for bpr parameterisation
  INTEGER(KIND=JPIM), PUBLIC, PARAMETER :: n_baran2018_asym =   3_JPIM !< Number of coefs for asym parameterisation

  !> Baran database wavelengths
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_wvl(n_baran2018_wn) = (/ &
&120.000_JPRB,100.000_JPRB, 95.170_JPRB, 90.800_JPRB, 85.000_JPRB,  &
& 80.000_JPRB, 75.000_JPRB, 70.530_JPRB, 67.600_JPRB, 65.580_JPRB,  &
& 63.780_JPRB, 60.000_JPRB, 57.460_JPRB, 55.000_JPRB, 53.500_JPRB,  &
& 50.030_JPRB, 47.360_JPRB, 45.500_JPRB, 42.760_JPRB, 41.140_JPRB,  &
& 39.600_JPRB, 38.240_JPRB, 37.000_JPRB, 35.640_JPRB, 34.480_JPRB,  &
& 33.330_JPRB, 31.000_JPRB, 28.570_JPRB, 26.000_JPRB, 25.000_JPRB,  &
& 24.600_JPRB, 23.600_JPRB, 23.050_JPRB, 22.600_JPRB, 22.220_JPRB,  &
& 20.830_JPRB, 20.410_JPRB, 20.000_JPRB, 19.610_JPRB, 19.230_JPRB,  &
& 18.870_JPRB, 18.610_JPRB, 18.320_JPRB, 18.180_JPRB, 17.240_JPRB,  &
& 16.670_JPRB, 16.130_JPRB, 15.630_JPRB, 15.150_JPRB, 14.710_JPRB,  &
& 14.290_JPRB, 14.080_JPRB, 13.700_JPRB, 13.510_JPRB, 13.330_JPRB,  &
& 12.990_JPRB, 12.820_JPRB, 12.500_JPRB, 12.200_JPRB, 11.900_JPRB,  &
& 11.630_JPRB, 11.360_JPRB, 11.000_JPRB, 10.750_JPRB, 10.530_JPRB,  &
& 10.310_JPRB, 10.200_JPRB, 10.000_JPRB,  9.804_JPRB,  9.259_JPRB,  &
&  9.091_JPRB,  8.696_JPRB,  8.475_JPRB,  8.333_JPRB,  8.065_JPRB,  &
&  7.812_JPRB,  7.463_JPRB,  7.246_JPRB,  7.042_JPRB,  6.757_JPRB,  &
&  6.494_JPRB,  6.410_JPRB,  6.329_JPRB,  6.250_JPRB,  6.061_JPRB,  &
&  5.814_JPRB,  5.747_JPRB,  5.556_JPRB,  5.263_JPRB,  5.200_JPRB,  &
&  5.000_JPRB,  4.900_JPRB,  4.700_JPRB,  4.500_JPRB,  4.300_JPRB,  &
&  4.100_JPRB,  3.925_JPRB,  3.775_JPRB,  3.650_JPRB,  3.550_JPRB,  &
&  3.450_JPRB,  3.350_JPRB,  3.275_JPRB,  3.225_JPRB,  3.188_JPRB,  &
&  3.162_JPRB,  3.138_JPRB,  3.112_JPRB,  3.088_JPRB,  3.062_JPRB,  &
&  3.037_JPRB,  3.013_JPRB,  2.987_JPRB,  2.963_JPRB,  2.888_JPRB,  &
&  2.862_JPRB,  2.838_JPRB,  2.812_JPRB,  2.750_JPRB,  2.650_JPRB,  &
&  2.500_JPRB,  2.350_JPRB,  2.250_JPRB,  2.150_JPRB,  2.050_JPRB,  &
&  1.975_JPRB,  1.925_JPRB,  1.850_JPRB,  1.725_JPRB,  1.575_JPRB,  &
&  1.450_JPRB,  1.350_JPRB,  1.250_JPRB,  1.150_JPRB,  1.050_JPRB,  &
&  0.950_JPRB,  0.870_JPRB,  0.650_JPRB,  0.551_JPRB,  0.476_JPRB,  &
&  0.425_JPRB,  0.350_JPRB,  0.275_JPRB,  0.225_JPRB,  0.200_JPRB/)
 
  !> Baran database wavenumbers
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_wvn(n_baran2018_wn) =(/ &
&    83.33_JPRB,   100.00_JPRB,   105.08_JPRB,   110.13_JPRB,   117.65_JPRB,  &
&   125.00_JPRB,   133.33_JPRB,   141.78_JPRB,   147.93_JPRB,   152.49_JPRB,  &
&   156.79_JPRB,   166.67_JPRB,   174.03_JPRB,   181.82_JPRB,   186.92_JPRB,  &
&   199.88_JPRB,   211.15_JPRB,   219.78_JPRB,   233.86_JPRB,   243.07_JPRB,  &
&   252.53_JPRB,   261.51_JPRB,   270.27_JPRB,   280.58_JPRB,   290.02_JPRB,  &
&   300.03_JPRB,   322.58_JPRB,   350.02_JPRB,   384.62_JPRB,   400.00_JPRB,  &
&   406.50_JPRB,   423.73_JPRB,   433.84_JPRB,   442.48_JPRB,   450.05_JPRB,  &
&   480.08_JPRB,   489.96_JPRB,   500.00_JPRB,   509.94_JPRB,   520.02_JPRB,  &
&   529.94_JPRB,   537.35_JPRB,   545.85_JPRB,   550.05_JPRB,   580.05_JPRB,  &
&   599.88_JPRB,   619.96_JPRB,   639.80_JPRB,   660.07_JPRB,   679.81_JPRB,  &
&   699.79_JPRB,   710.23_JPRB,   729.93_JPRB,   740.19_JPRB,   750.19_JPRB,  &
&   769.82_JPRB,   780.03_JPRB,   800.00_JPRB,   819.67_JPRB,   840.34_JPRB,  &
&   859.85_JPRB,   880.28_JPRB,   909.09_JPRB,   930.23_JPRB,   949.67_JPRB,  &
&   969.93_JPRB,   980.39_JPRB,  1000.00_JPRB,  1019.99_JPRB,  1080.03_JPRB,  &
&  1099.99_JPRB,  1149.95_JPRB,  1179.94_JPRB,  1200.05_JPRB,  1239.93_JPRB,  &
&  1280.08_JPRB,  1339.94_JPRB,  1380.07_JPRB,  1420.05_JPRB,  1479.95_JPRB,  &
&  1539.88_JPRB,  1560.06_JPRB,  1580.03_JPRB,  1600.00_JPRB,  1649.89_JPRB,  &
&  1719.99_JPRB,  1740.04_JPRB,  1799.86_JPRB,  1900.06_JPRB,  1923.08_JPRB,  &
&  2000.00_JPRB,  2040.82_JPRB,  2127.66_JPRB,  2222.22_JPRB,  2325.58_JPRB,  &
&  2439.02_JPRB,  2547.77_JPRB,  2649.01_JPRB,  2739.73_JPRB,  2816.90_JPRB,  &
&  2898.55_JPRB,  2985.07_JPRB,  3053.44_JPRB,  3100.78_JPRB,  3136.76_JPRB,  &
&  3162.56_JPRB,  3186.74_JPRB,  3213.37_JPRB,  3238.34_JPRB,  3265.84_JPRB,  &
&  3292.72_JPRB,  3318.95_JPRB,  3347.84_JPRB,  3374.96_JPRB,  3462.60_JPRB,  &
&  3494.06_JPRB,  3523.61_JPRB,  3556.19_JPRB,  3636.36_JPRB,  3773.58_JPRB,  &
&  4000.00_JPRB,  4255.32_JPRB,  4444.44_JPRB,  4651.16_JPRB,  4878.05_JPRB,  &
&  5063.29_JPRB,  5194.80_JPRB,  5405.41_JPRB,  5797.10_JPRB,  6349.21_JPRB,  &
&  6896.55_JPRB,  7407.41_JPRB,  8000.00_JPRB,  8695.65_JPRB,  9523.81_JPRB,  &
& 10526.32_JPRB, 11494.25_JPRB, 15384.62_JPRB, 18162.00_JPRB, 21030.49_JPRB,  &
& 23529.41_JPRB, 28571.43_JPRB, 36363.64_JPRB, 44444.45_JPRB, 50000.00_JPRB/)
 
  !> Baran regression coefficients for absorption coef
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_regcoef_abs(n_baran2018_abs, n_baran2018_wn) = &
  RESHAPE( (/ &
&   1.0344446_JPRB,      0.0034118_JPRB,      1.1583015_JPRB,     -0.0000104_JPRB,     -0.0183318_JPRB,     -0.0009399_JPRB,  &
&   1.2115146_JPRB,      0.0017859_JPRB,      1.0985985_JPRB,     -0.0000067_JPRB,     -0.0126532_JPRB,     -0.0006508_JPRB,  &
&   1.2505532_JPRB,      0.0016495_JPRB,      1.0967901_JPRB,     -0.0000067_JPRB,     -0.0128028_JPRB,     -0.0006619_JPRB,  &
&   1.3051117_JPRB,      0.0013114_JPRB,      1.0926375_JPRB,     -0.0000063_JPRB,     -0.0130369_JPRB,     -0.0006649_JPRB,  &
&   1.4062968_JPRB,      0.0005258_JPRB,      1.0809953_JPRB,     -0.0000048_JPRB,     -0.0132205_JPRB,     -0.0006437_JPRB,  &
&   1.4673627_JPRB,      0.0001245_JPRB,      1.0736622_JPRB,     -0.0000042_JPRB,     -0.0132777_JPRB,     -0.0006336_JPRB,  &
&   1.5358471_JPRB,     -0.0003574_JPRB,      1.0632290_JPRB,     -0.0000034_JPRB,     -0.0131467_JPRB,     -0.0006103_JPRB,  &
&   1.5936690_JPRB,     -0.0007590_JPRB,      1.0528512_JPRB,     -0.0000027_JPRB,     -0.0128762_JPRB,     -0.0005829_JPRB,  &
&   1.5882434_JPRB,     -0.0007543_JPRB,      1.0516044_JPRB,     -0.0000026_JPRB,     -0.0126159_JPRB,     -0.0005688_JPRB,  &
&   1.5995910_JPRB,     -0.0009338_JPRB,      1.0476779_JPRB,     -0.0000020_JPRB,     -0.0123735_JPRB,     -0.0005462_JPRB,  &
&   1.5808206_JPRB,     -0.0008230_JPRB,      1.0493467_JPRB,     -0.0000021_JPRB,     -0.0122230_JPRB,     -0.0005422_JPRB,  &
&   1.5324259_JPRB,     -0.0006506_JPRB,      1.0509197_JPRB,     -0.0000022_JPRB,     -0.0114953_JPRB,     -0.0005173_JPRB,  &
&   1.5340588_JPRB,     -0.0008343_JPRB,      1.0465120_JPRB,     -0.0000015_JPRB,     -0.0108007_JPRB,     -0.0004799_JPRB,  &
&   1.6609380_JPRB,     -0.0018115_JPRB,      1.0210183_JPRB,      0.0000002_JPRB,     -0.0100503_JPRB,     -0.0004072_JPRB,  &
&   1.6683811_JPRB,     -0.0017952_JPRB,      1.0196021_JPRB,      0.0000001_JPRB,     -0.0099751_JPRB,     -0.0004078_JPRB,  &
&   1.7111222_JPRB,     -0.0023035_JPRB,      0.9982082_JPRB,      0.0000014_JPRB,     -0.0081083_JPRB,     -0.0003004_JPRB,  &
&   1.7393924_JPRB,     -0.0025890_JPRB,      0.9801474_JPRB,      0.0000019_JPRB,     -0.0064261_JPRB,     -0.0002212_JPRB,  &
&   1.8039939_JPRB,     -0.0031763_JPRB,      0.9685000_JPRB,      0.0000034_JPRB,     -0.0060010_JPRB,     -0.0001683_JPRB,  &
&   1.5422684_JPRB,     -0.0006626_JPRB,      1.0443452_JPRB,     -0.0000019_JPRB,     -0.0107252_JPRB,     -0.0004748_JPRB,  &
&   1.5218563_JPRB,     -0.0004317_JPRB,      1.0547151_JPRB,     -0.0000024_JPRB,     -0.0117090_JPRB,     -0.0005243_JPRB,  &
&   1.5082706_JPRB,     -0.0003666_JPRB,      1.0570487_JPRB,     -0.0000025_JPRB,     -0.0117804_JPRB,     -0.0005272_JPRB,  &
&   1.5773402_JPRB,     -0.0010243_JPRB,      1.0407693_JPRB,     -0.0000010_JPRB,     -0.0109597_JPRB,     -0.0004601_JPRB,  &
&   1.4935747_JPRB,     -0.0003274_JPRB,      1.0619219_JPRB,     -0.0000025_JPRB,     -0.0123039_JPRB,     -0.0005464_JPRB,  &
&   1.4678969_JPRB,     -0.0002192_JPRB,      1.0637646_JPRB,     -0.0000025_JPRB,     -0.0121383_JPRB,     -0.0005397_JPRB,  &
&   1.4437437_JPRB,     -0.0001857_JPRB,      1.0623618_JPRB,     -0.0000023_JPRB,     -0.0115920_JPRB,     -0.0005121_JPRB,  &
&   1.4376100_JPRB,     -0.0003685_JPRB,      1.0505092_JPRB,     -0.0000015_JPRB,     -0.0098960_JPRB,     -0.0004266_JPRB,  &
&   1.2069481_JPRB,      0.0008027_JPRB,      1.0585576_JPRB,     -0.0000024_JPRB,     -0.0065831_JPRB,     -0.0003209_JPRB,  &
&   0.8220169_JPRB,      0.0030773_JPRB,      1.0888860_JPRB,     -0.0000053_JPRB,     -0.0027491_JPRB,     -0.0002515_JPRB,  &
&   0.4501997_JPRB,      0.0055181_JPRB,      1.1462216_JPRB,     -0.0000093_JPRB,     -0.0028078_JPRB,     -0.0003648_JPRB,  &
&   0.3801709_JPRB,      0.0059830_JPRB,      1.1696622_JPRB,     -0.0000101_JPRB,     -0.0045247_JPRB,     -0.0004566_JPRB,  &
&   0.3128783_JPRB,      0.0062375_JPRB,      1.1647323_JPRB,     -0.0000100_JPRB,     -0.0026546_JPRB,     -0.0003800_JPRB,  &
&   0.2005668_JPRB,      0.0075615_JPRB,      1.2082926_JPRB,     -0.0000136_JPRB,     -0.0061003_JPRB,     -0.0006033_JPRB,  &
&   0.1655611_JPRB,      0.0079659_JPRB,      1.2207285_JPRB,     -0.0000146_JPRB,     -0.0071370_JPRB,     -0.0006673_JPRB,  &
&   0.2042520_JPRB,      0.0077343_JPRB,      1.2243456_JPRB,     -0.0000143_JPRB,     -0.0083561_JPRB,     -0.0007058_JPRB,  &
&   0.2686746_JPRB,      0.0072817_JPRB,      1.2192185_JPRB,     -0.0000134_JPRB,     -0.0089860_JPRB,     -0.0007065_JPRB,  &
&   0.5687594_JPRB,      0.0053922_JPRB,      1.1764853_JPRB,     -0.0000104_JPRB,     -0.0089352_JPRB,     -0.0006282_JPRB,  &
&   0.7125478_JPRB,      0.0043729_JPRB,      1.1504930_JPRB,     -0.0000086_JPRB,     -0.0082902_JPRB,     -0.0005569_JPRB,  &
&   0.8504420_JPRB,      0.0033416_JPRB,      1.1232663_JPRB,     -0.0000067_JPRB,     -0.0074228_JPRB,     -0.0004741_JPRB,  &
&   0.9472541_JPRB,      0.0026806_JPRB,      1.1107275_JPRB,     -0.0000056_JPRB,     -0.0077230_JPRB,     -0.0004582_JPRB,  &
&   0.9181227_JPRB,      0.0029401_JPRB,      1.1212098_JPRB,     -0.0000062_JPRB,     -0.0085287_JPRB,     -0.0005054_JPRB,  &
&   0.9173258_JPRB,      0.0028837_JPRB,      1.1139685_JPRB,     -0.0000059_JPRB,     -0.0075855_JPRB,     -0.0004599_JPRB,  &
&   0.9640416_JPRB,      0.0025714_JPRB,      1.1090877_JPRB,     -0.0000055_JPRB,     -0.0079939_JPRB,     -0.0004619_JPRB,  &
&   0.9470780_JPRB,      0.0026002_JPRB,      1.1013473_JPRB,     -0.0000053_JPRB,     -0.0064835_JPRB,     -0.0004002_JPRB,  &
&   1.0030143_JPRB,      0.0021895_JPRB,      1.0976069_JPRB,     -0.0000046_JPRB,     -0.0071891_JPRB,     -0.0004105_JPRB,  &
&   1.1685778_JPRB,      0.0009639_JPRB,      1.0604081_JPRB,     -0.0000023_JPRB,     -0.0055837_JPRB,     -0.0002903_JPRB,  &
&   1.2407234_JPRB,      0.0000717_JPRB,      1.0267152_JPRB,      0.0000000_JPRB,     -0.0026448_JPRB,     -0.0001172_JPRB,  &
&   1.2675530_JPRB,     -0.0001171_JPRB,      1.0213100_JPRB,      0.0000003_JPRB,     -0.0024738_JPRB,     -0.0001023_JPRB,  &
&   1.3373516_JPRB,     -0.0005718_JPRB,      1.0105519_JPRB,      0.0000010_JPRB,     -0.0025267_JPRB,     -0.0000864_JPRB,  &
&   1.3846854_JPRB,     -0.0009361_JPRB,      0.9974732_JPRB,      0.0000017_JPRB,     -0.0016649_JPRB,     -0.0000361_JPRB,  &
&   1.4315711_JPRB,     -0.0013307_JPRB,      0.9836359_JPRB,      0.0000025_JPRB,     -0.0007006_JPRB,      0.0000189_JPRB,  &
&   1.4747368_JPRB,     -0.0016759_JPRB,      0.9712163_JPRB,      0.0000031_JPRB,      0.0001689_JPRB,      0.0000674_JPRB,  &
&   1.4904601_JPRB,     -0.0017988_JPRB,      0.9668869_JPRB,      0.0000034_JPRB,      0.0004712_JPRB,      0.0000840_JPRB,  &
&   1.5101435_JPRB,     -0.0019507_JPRB,      0.9614283_JPRB,      0.0000036_JPRB,      0.0008701_JPRB,      0.0001052_JPRB,  &
&   1.5165763_JPRB,     -0.0019984_JPRB,      0.9596500_JPRB,      0.0000037_JPRB,      0.0010053_JPRB,      0.0001120_JPRB,  &
&   1.5211447_JPRB,     -0.0020329_JPRB,      0.9582599_JPRB,      0.0000038_JPRB,      0.0011210_JPRB,      0.0001175_JPRB,  &
&   1.5288332_JPRB,     -0.0020812_JPRB,      0.9566073_JPRB,      0.0000038_JPRB,      0.0012368_JPRB,      0.0001227_JPRB,  &
&   1.5301935_JPRB,     -0.0020847_JPRB,      0.9564461_JPRB,      0.0000038_JPRB,      0.0012484_JPRB,      0.0001227_JPRB,  &
&   1.5293470_JPRB,     -0.0020607_JPRB,      0.9572728_JPRB,      0.0000038_JPRB,      0.0011848_JPRB,      0.0001180_JPRB,  &
&   1.5272340_JPRB,     -0.0020113_JPRB,      0.9597541_JPRB,      0.0000036_JPRB,      0.0009312_JPRB,      0.0001044_JPRB,  &
&   1.5234109_JPRB,     -0.0019367_JPRB,      0.9635900_JPRB,      0.0000034_JPRB,      0.0005293_JPRB,      0.0000836_JPRB,  &
&   1.5182816_JPRB,     -0.0018362_JPRB,      0.9690071_JPRB,      0.0000031_JPRB,     -0.0000552_JPRB,      0.0000542_JPRB,  &
&   1.5087028_JPRB,     -0.0016631_JPRB,      0.9774067_JPRB,      0.0000026_JPRB,     -0.0009213_JPRB,      0.0000091_JPRB,  &
&   1.4982295_JPRB,     -0.0013791_JPRB,      0.9947186_JPRB,      0.0000018_JPRB,     -0.0029866_JPRB,     -0.0000909_JPRB,  &
&   1.4872589_JPRB,     -0.0010975_JPRB,      1.0123952_JPRB,      0.0000009_JPRB,     -0.0051266_JPRB,     -0.0001937_JPRB,  &
&   1.4404081_JPRB,     -0.0007213_JPRB,      1.0285289_JPRB,      0.0000002_JPRB,     -0.0063683_JPRB,     -0.0002595_JPRB,  &
&   1.3051264_JPRB,     -0.0000073_JPRB,      1.0381424_JPRB,     -0.0000005_JPRB,     -0.0049135_JPRB,     -0.0002208_JPRB,  &
&   1.2117825_JPRB,      0.0005738_JPRB,      1.0487998_JPRB,     -0.0000013_JPRB,     -0.0044563_JPRB,     -0.0002230_JPRB,  &
&   1.0263683_JPRB,      0.0018940_JPRB,      1.0808466_JPRB,     -0.0000035_JPRB,     -0.0050180_JPRB,     -0.0003007_JPRB,  &
&   0.9233288_JPRB,      0.0027071_JPRB,      1.1048511_JPRB,     -0.0000051_JPRB,     -0.0062197_JPRB,     -0.0003860_JPRB,  &
&   0.8098193_JPRB,      0.0035643_JPRB,      1.1288206_JPRB,     -0.0000067_JPRB,     -0.0075761_JPRB,     -0.0004723_JPRB,  &
&   0.7874153_JPRB,      0.0037104_JPRB,      1.1292664_JPRB,     -0.0000069_JPRB,     -0.0072743_JPRB,     -0.0004641_JPRB,  &
&   0.8056908_JPRB,      0.0035747_JPRB,      1.1282448_JPRB,     -0.0000067_JPRB,     -0.0077177_JPRB,     -0.0004727_JPRB,  &
&   0.8335188_JPRB,      0.0033985_JPRB,      1.1260087_JPRB,     -0.0000065_JPRB,     -0.0079875_JPRB,     -0.0004773_JPRB,  &
&   0.8468329_JPRB,      0.0033297_JPRB,      1.1247226_JPRB,     -0.0000064_JPRB,     -0.0080514_JPRB,     -0.0004787_JPRB,  &
&   0.8930523_JPRB,      0.0030629_JPRB,      1.1205268_JPRB,     -0.0000061_JPRB,     -0.0084316_JPRB,     -0.0004853_JPRB,  &
&   0.9357406_JPRB,      0.0027570_JPRB,      1.1118969_JPRB,     -0.0000056_JPRB,     -0.0080949_JPRB,     -0.0004594_JPRB,  &
&   1.0201036_JPRB,      0.0020762_JPRB,      1.0890337_JPRB,     -0.0000042_JPRB,     -0.0066899_JPRB,     -0.0003712_JPRB,  &
&   1.0939092_JPRB,      0.0015506_JPRB,      1.0741302_JPRB,     -0.0000033_JPRB,     -0.0062184_JPRB,     -0.0003296_JPRB,  &
&   1.1275768_JPRB,      0.0012879_JPRB,      1.0652161_JPRB,     -0.0000028_JPRB,     -0.0056552_JPRB,     -0.0002956_JPRB,  &
&   1.1674628_JPRB,      0.0009677_JPRB,      1.0543415_JPRB,     -0.0000022_JPRB,     -0.0048970_JPRB,     -0.0002515_JPRB,  &
&   1.1924368_JPRB,      0.0007891_JPRB,      1.0489880_JPRB,     -0.0000018_JPRB,     -0.0046573_JPRB,     -0.0002346_JPRB,  &
&   1.2022854_JPRB,      0.0007151_JPRB,      1.0465628_JPRB,     -0.0000017_JPRB,     -0.0045100_JPRB,     -0.0002257_JPRB,  &
&   1.2136549_JPRB,      0.0006343_JPRB,      1.0442690_JPRB,     -0.0000016_JPRB,     -0.0044181_JPRB,     -0.0002187_JPRB,  &
&   1.2239578_JPRB,      0.0005548_JPRB,      1.0413118_JPRB,     -0.0000014_JPRB,     -0.0042014_JPRB,     -0.0002068_JPRB,  &
&   1.2284142_JPRB,      0.0005242_JPRB,      1.0399955_JPRB,     -0.0000013_JPRB,     -0.0040726_JPRB,     -0.0002005_JPRB,  &
&   1.1086348_JPRB,      0.0014737_JPRB,      1.0713336_JPRB,     -0.0000032_JPRB,     -0.0060801_JPRB,     -0.0003216_JPRB,  &
&   1.0524361_JPRB,      0.0019263_JPRB,      1.0878670_JPRB,     -0.0000041_JPRB,     -0.0073009_JPRB,     -0.0003904_JPRB,  &
&   0.8746039_JPRB,      0.0032350_JPRB,      1.1288170_JPRB,     -0.0000066_JPRB,     -0.0094332_JPRB,     -0.0005319_JPRB,  &
&   0.6427709_JPRB,      0.0048093_JPRB,      1.1684854_JPRB,     -0.0000092_JPRB,     -0.0102397_JPRB,     -0.0006302_JPRB,  &
&   0.6120820_JPRB,      0.0049766_JPRB,      1.1714289_JPRB,     -0.0000094_JPRB,     -0.0101253_JPRB,     -0.0006292_JPRB,  &
&   0.6170553_JPRB,      0.0048921_JPRB,      1.1637001_JPRB,     -0.0000091_JPRB,     -0.0092347_JPRB,     -0.0005867_JPRB,  &
&   0.4141266_JPRB,      0.0059154_JPRB,      1.1458838_JPRB,     -0.0000098_JPRB,     -0.0026858_JPRB,     -0.0003498_JPRB,  &
&   0.7604097_JPRB,      0.0035633_JPRB,      1.0981473_JPRB,     -0.0000059_JPRB,     -0.0027668_JPRB,     -0.0002626_JPRB,  &
&   0.9251867_JPRB,      0.0023235_JPRB,      1.0580287_JPRB,     -0.0000036_JPRB,     -0.0006267_JPRB,     -0.0001204_JPRB,  &
&   0.7634162_JPRB,      0.0035248_JPRB,      1.0897061_JPRB,     -0.0000059_JPRB,     -0.0018438_JPRB,     -0.0002222_JPRB,  &
&   0.6284591_JPRB,      0.0045449_JPRB,      1.1231930_JPRB,     -0.0000078_JPRB,     -0.0036167_JPRB,     -0.0003399_JPRB,  &
&   0.3694375_JPRB,      0.0062253_JPRB,      1.1525212_JPRB,     -0.0000104_JPRB,     -0.0028079_JPRB,     -0.0003693_JPRB,  &
&   0.2579298_JPRB,      0.0069274_JPRB,      1.1799234_JPRB,     -0.0000116_JPRB,     -0.0043804_JPRB,     -0.0004642_JPRB,  &
&   0.3588643_JPRB,      0.0062879_JPRB,      1.1633698_JPRB,     -0.0000106_JPRB,     -0.0040542_JPRB,     -0.0004262_JPRB,  &
&   0.6462620_JPRB,      0.0043497_JPRB,      1.1159653_JPRB,     -0.0000073_JPRB,     -0.0030485_JPRB,     -0.0003073_JPRB,  &
&   1.0074290_JPRB,      0.0016576_JPRB,      1.0385384_JPRB,     -0.0000024_JPRB,      0.0003636_JPRB,     -0.0000540_JPRB,  &
&   1.2400488_JPRB,      0.0000181_JPRB,      0.9956416_JPRB,      0.0000004_JPRB,      0.0018664_JPRB,      0.0000659_JPRB,  &
&   1.2753626_JPRB,     -0.0004957_JPRB,      0.9677938_JPRB,      0.0000019_JPRB,      0.0048728_JPRB,      0.0002170_JPRB,  &
&   1.2821720_JPRB,     -0.0003948_JPRB,      0.9759860_JPRB,      0.0000013_JPRB,      0.0037642_JPRB,      0.0001560_JPRB,  &
&   1.2761191_JPRB,     -0.0004344_JPRB,      0.9732230_JPRB,      0.0000014_JPRB,      0.0041266_JPRB,      0.0001736_JPRB,  &
&   1.2667178_JPRB,     -0.0004009_JPRB,      0.9734575_JPRB,      0.0000013_JPRB,      0.0041397_JPRB,      0.0001718_JPRB,  &
&   1.2585571_JPRB,     -0.0005565_JPRB,      0.9619809_JPRB,      0.0000020_JPRB,      0.0055946_JPRB,      0.0002458_JPRB,  &
&   1.2516051_JPRB,     -0.0004157_JPRB,      0.9719791_JPRB,      0.0000014_JPRB,      0.0043299_JPRB,      0.0001808_JPRB,  &
&   1.2511897_JPRB,     -0.0005326_JPRB,      0.9697881_JPRB,      0.0000016_JPRB,      0.0043507_JPRB,      0.0001865_JPRB,  &
&   1.2297153_JPRB,     -0.0004750_JPRB,      0.9694331_JPRB,      0.0000015_JPRB,      0.0045310_JPRB,      0.0001917_JPRB,  &
&   1.2096504_JPRB,     -0.0005967_JPRB,      0.9567689_JPRB,      0.0000022_JPRB,      0.0063369_JPRB,      0.0002831_JPRB,  &
&   1.2302596_JPRB,     -0.0005061_JPRB,      0.9714021_JPRB,      0.0000016_JPRB,      0.0041388_JPRB,      0.0001784_JPRB,  &
&   1.2405563_JPRB,     -0.0005267_JPRB,      0.9740496_JPRB,      0.0000016_JPRB,      0.0036932_JPRB,      0.0001619_JPRB,  &
&   1.2380537_JPRB,     -0.0004124_JPRB,      0.9786727_JPRB,      0.0000013_JPRB,      0.0032572_JPRB,      0.0001387_JPRB,  &
&   1.2305723_JPRB,      0.0001143_JPRB,      1.0070287_JPRB,     -0.0000000_JPRB,      0.0002946_JPRB,     -0.0000060_JPRB,  &
&   1.2092814_JPRB,      0.0004699_JPRB,      1.0235191_JPRB,     -0.0000007_JPRB,     -0.0011661_JPRB,     -0.0000782_JPRB,  &
&   1.1408566_JPRB,      0.0010448_JPRB,      1.0419134_JPRB,     -0.0000018_JPRB,     -0.0022536_JPRB,     -0.0001447_JPRB,  &
&   0.9826522_JPRB,      0.0019783_JPRB,      1.0523844_JPRB,     -0.0000029_JPRB,     -0.0008020_JPRB,     -0.0001097_JPRB,  &
&   0.2238656_JPRB,      0.0073974_JPRB,      1.1994593_JPRB,     -0.0000128_JPRB,     -0.0061103_JPRB,     -0.0005585_JPRB,  &
&  -0.9134854_JPRB,      0.0128528_JPRB,      1.3070639_JPRB,     -0.0000198_JPRB,     -0.0022080_JPRB,     -0.0005883_JPRB,  &
&  -0.9606522_JPRB,      0.0126084_JPRB,      1.3168171_JPRB,     -0.0000192_JPRB,     -0.0037301_JPRB,     -0.0006390_JPRB,  &
&  -1.2473454_JPRB,      0.0135637_JPRB,      1.3234148_JPRB,     -0.0000200_JPRB,     -0.0010221_JPRB,     -0.0005539_JPRB,  &
&  -1.4897654_JPRB,      0.0130384_JPRB,      1.3279371_JPRB,     -0.0000180_JPRB,     -0.0013542_JPRB,     -0.0005261_JPRB,  &
&  -1.2535522_JPRB,      0.0135883_JPRB,      1.3244090_JPRB,     -0.0000201_JPRB,     -0.0011424_JPRB,     -0.0005611_JPRB,  &
&  -0.4750902_JPRB,      0.0109457_JPRB,      1.2771575_JPRB,     -0.0000176_JPRB,     -0.0048209_JPRB,     -0.0006337_JPRB,  &
&  -0.4633750_JPRB,      0.0110800_JPRB,      1.2652220_JPRB,     -0.0000178_JPRB,     -0.0031357_JPRB,     -0.0005695_JPRB,  &
&  -0.7824495_JPRB,      0.0120462_JPRB,      1.3031556_JPRB,     -0.0000187_JPRB,     -0.0041566_JPRB,     -0.0006386_JPRB,  &
&  -1.6576373_JPRB,      0.0136451_JPRB,      1.3281558_JPRB,     -0.0000186_JPRB,      0.0007794_JPRB,     -0.0004586_JPRB,  &
&  -1.4281636_JPRB,      0.0129606_JPRB,      1.3274110_JPRB,     -0.0000181_JPRB,     -0.0018205_JPRB,     -0.0005448_JPRB,  &
&  -1.1467121_JPRB,      0.0133312_JPRB,      1.3202870_JPRB,     -0.0000199_JPRB,     -0.0017539_JPRB,     -0.0005779_JPRB,  &
&  -1.2426179_JPRB,      0.0128471_JPRB,      1.3302443_JPRB,     -0.0000186_JPRB,     -0.0035635_JPRB,     -0.0006200_JPRB,  &
&  -2.5357991_JPRB,      0.0143291_JPRB,      1.3453132_JPRB,     -0.0000202_JPRB,     -0.0000681_JPRB,     -0.0005218_JPRB,  &
&  -2.3678559_JPRB,      0.0126871_JPRB,      1.3256183_JPRB,     -0.0000157_JPRB,      0.0001533_JPRB,     -0.0004179_JPRB,  &
&  -3.0151511_JPRB,      0.0119372_JPRB,      1.3141821_JPRB,     -0.0000136_JPRB,      0.0005539_JPRB,     -0.0003477_JPRB,  &
&  -3.0255711_JPRB,      0.0123142_JPRB,      1.3233827_JPRB,     -0.0000147_JPRB,      0.0006511_JPRB,     -0.0003896_JPRB,  &
&  -3.5077202_JPRB,      0.0104868_JPRB,      1.5502182_JPRB,     -0.0000121_JPRB,      0.0290935_JPRB,     -0.0008809_JPRB,  &
&  -3.5077202_JPRB,      0.0104868_JPRB,      1.5502182_JPRB,     -0.0000121_JPRB,      0.0290935_JPRB,     -0.0008809_JPRB,  &
&  -4.2543957_JPRB,      0.0108884_JPRB,      1.8510359_JPRB,     -0.0000157_JPRB,      0.1305763_JPRB,     -0.0008307_JPRB,  &
&  -5.7691206_JPRB,      0.0206862_JPRB,      1.8910011_JPRB,     -0.0000281_JPRB,      0.1919801_JPRB,      0.0002301_JPRB,  &
&  -7.5476552_JPRB,      0.0244887_JPRB,      1.4549095_JPRB,     -0.0000287_JPRB,      0.2677604_JPRB,      0.0026060_JPRB,  &
&  -7.9961998_JPRB,      0.0188183_JPRB,      1.0934073_JPRB,     -0.0000140_JPRB,      0.2687525_JPRB,      0.0035399_JPRB,  &
&  -7.8513129_JPRB,      0.0133629_JPRB,      0.7987865_JPRB,      0.0000020_JPRB,      0.2643248_JPRB,      0.0044645_JPRB,  &
&  -7.9953830_JPRB,      0.0165969_JPRB,      0.9275819_JPRB,     -0.0000056_JPRB,      0.2688727_JPRB,      0.0042006_JPRB,  &
&  -4.9840921_JPRB,      0.0101759_JPRB,      1.8445068_JPRB,     -0.0000351_JPRB,      0.1796742_JPRB,     -0.0017886_JPRB,  &
&  -3.8813627_JPRB,      0.0004696_JPRB,      1.7387990_JPRB,     -0.0000084_JPRB,      0.1838359_JPRB,     -0.0010016_JPRB/),&
&     SHAPE =(/ n_baran2018_abs, n_baran2018_wn/))
 
  !> Baran regression coefficients for scattering coef
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_regcoef_sca(n_baran2018_sca, n_baran2018_wn) =  &
  RESHAPE( (/ &
&   1.3940927_JPRB,      0.0018602_JPRB,      1.2674520_JPRB,     -0.0000095_JPRB,     -0.0399837_JPRB,     -0.0017483_JPRB,  &
&   1.3741918_JPRB,      0.0017767_JPRB,      1.2383202_JPRB,     -0.0000087_JPRB,     -0.0344615_JPRB,     -0.0015341_JPRB,  &
&   1.3857801_JPRB,      0.0014299_JPRB,      1.2189110_JPRB,     -0.0000075_JPRB,     -0.0319313_JPRB,     -0.0014109_JPRB,  &
&   1.3724995_JPRB,      0.0013201_JPRB,      1.2049115_JPRB,     -0.0000068_JPRB,     -0.0296380_JPRB,     -0.0013074_JPRB,  &
&   1.3705355_JPRB,      0.0009664_JPRB,      1.1845431_JPRB,     -0.0000053_JPRB,     -0.0266864_JPRB,     -0.0011621_JPRB,  &
&   1.3405057_JPRB,      0.0009371_JPRB,      1.1715534_JPRB,     -0.0000046_JPRB,     -0.0241845_JPRB,     -0.0010512_JPRB,  &
&   1.2837174_JPRB,      0.0011287_JPRB,      1.1639081_JPRB,     -0.0000044_JPRB,     -0.0218799_JPRB,     -0.0009577_JPRB,  &
&   1.1758267_JPRB,      0.0017805_JPRB,      1.1756843_JPRB,     -0.0000052_JPRB,     -0.0213400_JPRB,     -0.0009565_JPRB,  &
&   1.1422602_JPRB,      0.0019872_JPRB,      1.1771589_JPRB,     -0.0000055_JPRB,     -0.0208504_JPRB,     -0.0009448_JPRB,  &
&   1.1426642_JPRB,      0.0018817_JPRB,      1.1757358_JPRB,     -0.0000051_JPRB,     -0.0207856_JPRB,     -0.0009330_JPRB,  &
&   1.1480787_JPRB,      0.0018640_JPRB,      1.1762484_JPRB,     -0.0000052_JPRB,     -0.0209902_JPRB,     -0.0009421_JPRB,  &
&   1.2830352_JPRB,      0.0010288_JPRB,      1.1543071_JPRB,     -0.0000039_JPRB,     -0.0205401_JPRB,     -0.0008942_JPRB,  &
&   1.4505530_JPRB,     -0.0003766_JPRB,      1.0964751_JPRB,     -0.0000008_JPRB,     -0.0155745_JPRB,     -0.0006315_JPRB,  &
&   1.3360778_JPRB,      0.0001839_JPRB,      1.0985940_JPRB,     -0.0000011_JPRB,     -0.0135996_JPRB,     -0.0005588_JPRB,  &
&   1.2776639_JPRB,      0.0006732_JPRB,      1.1095318_JPRB,     -0.0000020_JPRB,     -0.0137637_JPRB,     -0.0005899_JPRB,  &
&   1.2519428_JPRB,      0.0007168_JPRB,      1.0980384_JPRB,     -0.0000017_JPRB,     -0.0115615_JPRB,     -0.0004965_JPRB,  &
&   1.1022209_JPRB,      0.0019520_JPRB,      1.1267761_JPRB,     -0.0000039_JPRB,     -0.0122313_JPRB,     -0.0005768_JPRB,  &
&   0.9488665_JPRB,      0.0029303_JPRB,      1.1505801_JPRB,     -0.0000055_JPRB,     -0.0126664_JPRB,     -0.0006313_JPRB,  &
&   0.5780047_JPRB,      0.0058766_JPRB,      1.2618714_JPRB,     -0.0000120_JPRB,     -0.0214162_JPRB,     -0.0011222_JPRB,  &
&   0.5598536_JPRB,      0.0060278_JPRB,      1.2713362_JPRB,     -0.0000124_JPRB,     -0.0224688_JPRB,     -0.0011738_JPRB,  &
&   0.6175390_JPRB,      0.0056366_JPRB,      1.2632929_JPRB,     -0.0000118_JPRB,     -0.0225577_JPRB,     -0.0011629_JPRB,  &
&   0.6614674_JPRB,      0.0052011_JPRB,      1.2371615_JPRB,     -0.0000107_JPRB,     -0.0196353_JPRB,     -0.0010250_JPRB,  &
&   0.6617332_JPRB,      0.0054141_JPRB,      1.2553337_JPRB,     -0.0000116_JPRB,     -0.0222963_JPRB,     -0.0011472_JPRB,  &
&   0.7535207_JPRB,      0.0048217_JPRB,      1.2442014_JPRB,     -0.0000107_JPRB,     -0.0226074_JPRB,     -0.0011383_JPRB,  &
&   0.8579248_JPRB,      0.0041859_JPRB,      1.2309195_JPRB,     -0.0000099_JPRB,     -0.0228150_JPRB,     -0.0011258_JPRB,  &
&   1.0356008_JPRB,      0.0028852_JPRB,      1.1936054_JPRB,     -0.0000075_JPRB,     -0.0210877_JPRB,     -0.0010037_JPRB,  &
&   1.3556036_JPRB,      0.0010115_JPRB,      1.1501298_JPRB,     -0.0000051_JPRB,     -0.0212068_JPRB,     -0.0009526_JPRB,  &
&   1.6734760_JPRB,     -0.0009818_JPRB,      1.0885630_JPRB,     -0.0000020_JPRB,     -0.0184371_JPRB,     -0.0007755_JPRB,  &
&   1.8416244_JPRB,     -0.0021688_JPRB,      1.0402560_JPRB,      0.0000004_JPRB,     -0.0146163_JPRB,     -0.0005716_JPRB,  &
&   1.8921054_JPRB,     -0.0025622_JPRB,      1.0248524_JPRB,      0.0000012_JPRB,     -0.0134567_JPRB,     -0.0005060_JPRB,  &
&   1.8996202_JPRB,     -0.0025394_JPRB,      1.0249829_JPRB,      0.0000011_JPRB,     -0.0134837_JPRB,     -0.0005116_JPRB,  &
&   1.9555307_JPRB,     -0.0032090_JPRB,      1.0026393_JPRB,      0.0000029_JPRB,     -0.0114515_JPRB,     -0.0003912_JPRB,  &
&   1.9830788_JPRB,     -0.0035744_JPRB,      0.9894709_JPRB,      0.0000039_JPRB,     -0.0102090_JPRB,     -0.0003195_JPRB,  &
&   1.9978578_JPRB,     -0.0038146_JPRB,      0.9789161_JPRB,      0.0000045_JPRB,     -0.0092393_JPRB,     -0.0002653_JPRB,  &
&   1.9993097_JPRB,     -0.0039048_JPRB,      0.9737241_JPRB,      0.0000048_JPRB,     -0.0087115_JPRB,     -0.0002380_JPRB,  &
&   2.0035216_JPRB,     -0.0043735_JPRB,      0.9547186_JPRB,      0.0000064_JPRB,     -0.0066388_JPRB,     -0.0001172_JPRB,  &
&   1.9814911_JPRB,     -0.0044047_JPRB,      0.9491591_JPRB,      0.0000068_JPRB,     -0.0055747_JPRB,     -0.0000646_JPRB,  &
&   1.9376305_JPRB,     -0.0042265_JPRB,      0.9486555_JPRB,      0.0000068_JPRB,     -0.0047026_JPRB,     -0.0000303_JPRB,  &
&   1.9016015_JPRB,     -0.0040932_JPRB,      0.9469515_JPRB,      0.0000069_JPRB,     -0.0037901_JPRB,      0.0000067_JPRB,  &
&   1.8590476_JPRB,     -0.0036450_JPRB,      0.9643704_JPRB,      0.0000057_JPRB,     -0.0053061_JPRB,     -0.0000797_JPRB,  &
&   1.9033965_JPRB,     -0.0041597_JPRB,      0.9415899_JPRB,      0.0000071_JPRB,     -0.0030161_JPRB,      0.0000420_JPRB,  &
&   1.8896253_JPRB,     -0.0041428_JPRB,      0.9380660_JPRB,      0.0000073_JPRB,     -0.0022186_JPRB,      0.0000765_JPRB,  &
&   1.8853713_JPRB,     -0.0040473_JPRB,      0.9409975_JPRB,      0.0000070_JPRB,     -0.0025654_JPRB,      0.0000572_JPRB,  &
&   1.8634636_JPRB,     -0.0039304_JPRB,      0.9391136_JPRB,      0.0000070_JPRB,     -0.0018474_JPRB,      0.0000834_JPRB,  &
&   1.7648877_JPRB,     -0.0033658_JPRB,      0.9442055_JPRB,      0.0000064_JPRB,     -0.0005144_JPRB,      0.0001206_JPRB,  &
&   1.6888416_JPRB,     -0.0025600_JPRB,      0.9650142_JPRB,      0.0000045_JPRB,     -0.0016401_JPRB,      0.0000306_JPRB,  &
&   1.6654811_JPRB,     -0.0024235_JPRB,      0.9645477_JPRB,      0.0000044_JPRB,     -0.0010646_JPRB,      0.0000494_JPRB,  &
&   1.6115039_JPRB,     -0.0021192_JPRB,      0.9658789_JPRB,      0.0000041_JPRB,     -0.0000391_JPRB,      0.0000810_JPRB,  &
&   1.5609941_JPRB,     -0.0017554_JPRB,      0.9720638_JPRB,      0.0000035_JPRB,      0.0001789_JPRB,      0.0000746_JPRB,  &
&   1.4916504_JPRB,     -0.0012432_JPRB,      0.9826158_JPRB,      0.0000026_JPRB,      0.0002397_JPRB,      0.0000561_JPRB,  &
&   1.4294849_JPRB,     -0.0007311_JPRB,      0.9965877_JPRB,      0.0000016_JPRB,     -0.0003854_JPRB,      0.0000077_JPRB,  &
&   1.4027806_JPRB,     -0.0005057_JPRB,      1.0033558_JPRB,      0.0000012_JPRB,     -0.0007726_JPRB,     -0.0000182_JPRB,  &
&   1.3619719_JPRB,     -0.0001530_JPRB,      1.0147440_JPRB,      0.0000004_JPRB,     -0.0015220_JPRB,     -0.0000648_JPRB,  &
&   1.3449120_JPRB,     -0.0000037_JPRB,      1.0197976_JPRB,      0.0000001_JPRB,     -0.0018798_JPRB,     -0.0000862_JPRB,  &
&   1.3301078_JPRB,      0.0001284_JPRB,      1.0243980_JPRB,     -0.0000002_JPRB,     -0.0022203_JPRB,     -0.0001062_JPRB,  &
&   1.2998880_JPRB,      0.0003957_JPRB,      1.0340723_JPRB,     -0.0000008_JPRB,     -0.0029719_JPRB,     -0.0001490_JPRB,  &
&   1.2864401_JPRB,      0.0005168_JPRB,      1.0387826_JPRB,     -0.0000010_JPRB,     -0.0033649_JPRB,     -0.0001706_JPRB,  &
&   1.2620715_JPRB,      0.0007379_JPRB,      1.0478216_JPRB,     -0.0000016_JPRB,     -0.0041579_JPRB,     -0.0002134_JPRB,  &
&   1.2357996_JPRB,      0.0009671_JPRB,      1.0573563_JPRB,     -0.0000021_JPRB,     -0.0050079_JPRB,     -0.0002586_JPRB,  &
&   1.2056204_JPRB,      0.0012257_JPRB,      1.0681983_JPRB,     -0.0000027_JPRB,     -0.0059756_JPRB,     -0.0003100_JPRB,  &
&   1.1719645_JPRB,      0.0015060_JPRB,      1.0801099_JPRB,     -0.0000033_JPRB,     -0.0070453_JPRB,     -0.0003665_JPRB,  &
&   1.1285931_JPRB,      0.0018326_JPRB,      1.0934199_JPRB,     -0.0000040_JPRB,     -0.0081679_JPRB,     -0.0004261_JPRB,  &
&   1.0226621_JPRB,      0.0026802_JPRB,      1.1281545_JPRB,     -0.0000059_JPRB,     -0.0111147_JPRB,     -0.0005844_JPRB,  &
&   0.9453863_JPRB,      0.0033157_JPRB,      1.1569983_JPRB,     -0.0000074_JPRB,     -0.0138208_JPRB,     -0.0007240_JPRB,  &
&   1.0310226_JPRB,      0.0026990_JPRB,      1.1443353_JPRB,     -0.0000065_JPRB,     -0.0139468_JPRB,     -0.0007040_JPRB,  &
&   1.3349424_JPRB,      0.0004920_JPRB,      1.0853202_JPRB,     -0.0000025_JPRB,     -0.0117836_JPRB,     -0.0005276_JPRB,  &
&   1.4670244_JPRB,     -0.0004861_JPRB,      1.0576396_JPRB,     -0.0000007_JPRB,     -0.0105206_JPRB,     -0.0004372_JPRB,  &
&   1.6517210_JPRB,     -0.0019170_JPRB,      1.0145925_JPRB,      0.0000020_JPRB,     -0.0081967_JPRB,     -0.0002821_JPRB,  &
&   1.7383217_JPRB,     -0.0026629_JPRB,      0.9882492_JPRB,      0.0000036_JPRB,     -0.0062826_JPRB,     -0.0001688_JPRB,  &
&   1.8212005_JPRB,     -0.0033832_JPRB,      0.9565992_JPRB,      0.0000053_JPRB,     -0.0033831_JPRB,     -0.0000183_JPRB,  &
&   1.8339589_JPRB,     -0.0034643_JPRB,      0.9529461_JPRB,      0.0000055_JPRB,     -0.0030744_JPRB,     -0.0000033_JPRB,  &
&   1.8074316_JPRB,     -0.0033490_JPRB,      0.9460779_JPRB,      0.0000055_JPRB,     -0.0015368_JPRB,      0.0000579_JPRB,  &
&   1.7977355_JPRB,     -0.0033388_JPRB,      0.9412310_JPRB,      0.0000057_JPRB,     -0.0006498_JPRB,      0.0000957_JPRB,  &
&   1.7948199_JPRB,     -0.0033597_JPRB,      0.9381636_JPRB,      0.0000058_JPRB,     -0.0001683_JPRB,      0.0001178_JPRB,  &
&   1.7864914_JPRB,     -0.0034103_JPRB,      0.9316898_JPRB,      0.0000062_JPRB,      0.0009133_JPRB,      0.0001678_JPRB,  &
&   1.7692589_JPRB,     -0.0033427_JPRB,      0.9293531_JPRB,      0.0000062_JPRB,      0.0016110_JPRB,      0.0001954_JPRB,  &
&   1.7190968_JPRB,     -0.0030184_JPRB,      0.9329787_JPRB,      0.0000058_JPRB,      0.0022130_JPRB,      0.0002073_JPRB,  &
&   1.6757852_JPRB,     -0.0027785_JPRB,      0.9351858_JPRB,      0.0000056_JPRB,      0.0028533_JPRB,      0.0002259_JPRB,  &
&   1.6488733_JPRB,     -0.0025899_JPRB,      0.9381641_JPRB,      0.0000053_JPRB,      0.0030084_JPRB,      0.0002246_JPRB,  &
&   1.6108803_JPRB,     -0.0023021_JPRB,      0.9438263_JPRB,      0.0000047_JPRB,      0.0029962_JPRB,      0.0002119_JPRB,  &
&   1.5861770_JPRB,     -0.0021335_JPRB,      0.9464278_JPRB,      0.0000045_JPRB,      0.0031600_JPRB,      0.0002117_JPRB,  &
&   1.5761659_JPRB,     -0.0020611_JPRB,      0.9479293_JPRB,      0.0000044_JPRB,      0.0031585_JPRB,      0.0002086_JPRB,  &
&   1.5653889_JPRB,     -0.0019873_JPRB,      0.9493474_JPRB,      0.0000042_JPRB,      0.0031882_JPRB,      0.0002068_JPRB,  &
&   1.5544290_JPRB,     -0.0019042_JPRB,      0.9515912_JPRB,      0.0000041_JPRB,      0.0030985_JPRB,      0.0001996_JPRB,  &
&   1.5469808_JPRB,     -0.0018397_JPRB,      0.9544209_JPRB,      0.0000039_JPRB,      0.0028316_JPRB,      0.0001856_JPRB,  &
&   1.6428897_JPRB,     -0.0025426_JPRB,      0.9370236_JPRB,      0.0000052_JPRB,      0.0032929_JPRB,      0.0002326_JPRB,  &
&   1.6814717_JPRB,     -0.0028172_JPRB,      0.9295754_JPRB,      0.0000056_JPRB,      0.0035618_JPRB,      0.0002541_JPRB,  &
&   1.7648685_JPRB,     -0.0032863_JPRB,      0.9198976_JPRB,      0.0000062_JPRB,      0.0032823_JPRB,      0.0002564_JPRB,  &
&   1.8076871_JPRB,     -0.0033174_JPRB,      0.9223998_JPRB,      0.0000057_JPRB,      0.0022974_JPRB,      0.0002069_JPRB,  &
&   1.8079297_JPRB,     -0.0032112_JPRB,      0.9261790_JPRB,      0.0000053_JPRB,      0.0018503_JPRB,      0.0001793_JPRB,  &
&   1.7895414_JPRB,     -0.0029646_JPRB,      0.9319072_JPRB,      0.0000046_JPRB,      0.0015320_JPRB,      0.0001500_JPRB,  &
&   1.7353236_JPRB,     -0.0021771_JPRB,      0.9583760_JPRB,      0.0000025_JPRB,     -0.0007143_JPRB,      0.0000113_JPRB,  &
&   1.6892131_JPRB,     -0.0022333_JPRB,      0.9480608_JPRB,      0.0000034_JPRB,      0.0013992_JPRB,      0.0001142_JPRB,  &
&   1.5985149_JPRB,     -0.0016568_JPRB,      0.9606523_JPRB,      0.0000025_JPRB,      0.0014962_JPRB,      0.0000961_JPRB,  &
&   1.6588369_JPRB,     -0.0019943_JPRB,      0.9536989_JPRB,      0.0000030_JPRB,      0.0013777_JPRB,      0.0001020_JPRB,  &
&   1.7059685_JPRB,     -0.0022772_JPRB,      0.9438058_JPRB,      0.0000034_JPRB,      0.0017483_JPRB,      0.0001271_JPRB,  &
&   1.7568306_JPRB,     -0.0023683_JPRB,      0.9457121_JPRB,      0.0000031_JPRB,      0.0007354_JPRB,      0.0000802_JPRB,  &
&   1.7706859_JPRB,     -0.0023441_JPRB,      0.9449397_JPRB,      0.0000029_JPRB,      0.0006568_JPRB,      0.0000753_JPRB,  &
&   1.7638006_JPRB,     -0.0024019_JPRB,      0.9443327_JPRB,      0.0000032_JPRB,      0.0007739_JPRB,      0.0000856_JPRB,  &
&   1.7150076_JPRB,     -0.0023218_JPRB,      0.9484245_JPRB,      0.0000034_JPRB,      0.0009966_JPRB,      0.0000987_JPRB,  &
&   1.5579835_JPRB,     -0.0013295_JPRB,      0.9740336_JPRB,      0.0000019_JPRB,      0.0006513_JPRB,      0.0000465_JPRB,  &
&   1.4223905_JPRB,     -0.0004885_JPRB,      0.9890863_JPRB,      0.0000009_JPRB,      0.0012732_JPRB,      0.0000461_JPRB,  &
&   1.3991214_JPRB,     -0.0001784_JPRB,      1.0046566_JPRB,      0.0000000_JPRB,     -0.0003238_JPRB,     -0.0000354_JPRB,  &
&   1.3945325_JPRB,     -0.0002326_JPRB,      1.0010187_JPRB,      0.0000004_JPRB,      0.0001604_JPRB,     -0.0000050_JPRB,  &
&   1.4006627_JPRB,     -0.0002476_JPRB,      1.0036726_JPRB,      0.0000004_JPRB,     -0.0003063_JPRB,     -0.0000209_JPRB,  &
&   1.4039895_JPRB,     -0.0001966_JPRB,      1.0073768_JPRB,      0.0000002_JPRB,     -0.0008058_JPRB,     -0.0000448_JPRB,  &
&   1.4115629_JPRB,     -0.0001110_JPRB,      1.0140650_JPRB,     -0.0000001_JPRB,     -0.0016355_JPRB,     -0.0000876_JPRB,  &
&   1.4125817_JPRB,     -0.0001603_JPRB,      1.0113760_JPRB,      0.0000001_JPRB,     -0.0013587_JPRB,     -0.0000686_JPRB,  &
&   1.4186490_JPRB,     -0.0001247_JPRB,      1.0139095_JPRB,      0.0000000_JPRB,     -0.0016752_JPRB,     -0.0000827_JPRB,  &
&   1.4295642_JPRB,     -0.0001085_JPRB,      1.0175909_JPRB,     -0.0000001_JPRB,     -0.0022221_JPRB,     -0.0001065_JPRB,  &
&   1.4432349_JPRB,     -0.0000638_JPRB,      1.0270345_JPRB,     -0.0000005_JPRB,     -0.0036585_JPRB,     -0.0001728_JPRB,  &
&   1.4313522_JPRB,     -0.0000878_JPRB,      1.0243326_JPRB,     -0.0000003_JPRB,     -0.0032341_JPRB,     -0.0001490_JPRB,  &
&   1.4178320_JPRB,     -0.0000017_JPRB,      1.0277362_JPRB,     -0.0000005_JPRB,     -0.0035717_JPRB,     -0.0001660_JPRB,  &
&   1.4216802_JPRB,     -0.0000605_JPRB,      1.0296463_JPRB,     -0.0000004_JPRB,     -0.0040335_JPRB,     -0.0001833_JPRB,  &
&   1.4071665_JPRB,     -0.0000792_JPRB,      1.0461827_JPRB,     -0.0000008_JPRB,     -0.0068860_JPRB,     -0.0003018_JPRB,  &
&   1.4152198_JPRB,     -0.0001367_JPRB,      1.0600060_JPRB,     -0.0000011_JPRB,     -0.0094019_JPRB,     -0.0004071_JPRB,  &
&   1.4570784_JPRB,     -0.0004481_JPRB,      1.0549217_JPRB,     -0.0000007_JPRB,     -0.0096977_JPRB,     -0.0004096_JPRB,  &
&   1.5714573_JPRB,     -0.0011694_JPRB,      1.0340321_JPRB,      0.0000004_JPRB,     -0.0088665_JPRB,     -0.0003538_JPRB,  &
&   1.8159390_JPRB,     -0.0026713_JPRB,      0.9588936_JPRB,      0.0000031_JPRB,     -0.0027598_JPRB,     -0.0000481_JPRB,  &
&   1.6429630_JPRB,     -0.0002499_JPRB,      1.0024241_JPRB,     -0.0000015_JPRB,     -0.0025177_JPRB,     -0.0001510_JPRB,  &
&   1.6469293_JPRB,     -0.0003114_JPRB,      0.9922275_JPRB,     -0.0000010_JPRB,     -0.0008145_JPRB,     -0.0000715_JPRB,  &
&   1.6373471_JPRB,     -0.0001792_JPRB,      0.9971329_JPRB,     -0.0000009_JPRB,     -0.0007705_JPRB,     -0.0000694_JPRB,  &
&   1.6290022_JPRB,     -0.0001027_JPRB,      1.0000062_JPRB,     -0.0000005_JPRB,     -0.0003338_JPRB,     -0.0000436_JPRB,  &
&   1.6307523_JPRB,     -0.0000795_JPRB,      1.0049364_JPRB,     -0.0000012_JPRB,     -0.0016892_JPRB,     -0.0001128_JPRB,  &
&   1.6830224_JPRB,     -0.0007744_JPRB,      0.9960065_JPRB,     -0.0000009_JPRB,     -0.0032417_JPRB,     -0.0001661_JPRB,  &
&   1.6913335_JPRB,     -0.0008690_JPRB,      0.9960964_JPRB,     -0.0000008_JPRB,     -0.0035914_JPRB,     -0.0001794_JPRB,  &
&   1.6530586_JPRB,     -0.0003524_JPRB,      1.0039535_JPRB,     -0.0000013_JPRB,     -0.0029137_JPRB,     -0.0001640_JPRB,  &
&   1.6195491_JPRB,      0.0000162_JPRB,      1.0068944_JPRB,     -0.0000008_JPRB,     -0.0009013_JPRB,     -0.0000732_JPRB,  &
&   1.6210904_JPRB,     -0.0000044_JPRB,      1.0041689_JPRB,     -0.0000009_JPRB,     -0.0007332_JPRB,     -0.0000696_JPRB,  &
&   1.6297775_JPRB,     -0.0001221_JPRB,      0.9984626_JPRB,     -0.0000012_JPRB,     -0.0008392_JPRB,     -0.0000813_JPRB,  &
&   1.6217041_JPRB,     -0.0000628_JPRB,      0.9945839_JPRB,     -0.0000009_JPRB,      0.0003135_JPRB,     -0.0000295_JPRB,  &
&   1.6197433_JPRB,     -0.0000691_JPRB,      0.9971468_JPRB,      0.0000001_JPRB,      0.0011919_JPRB,      0.0000274_JPRB,  &
&   1.6218438_JPRB,     -0.0000767_JPRB,      0.9980152_JPRB,      0.0000001_JPRB,      0.0009863_JPRB,      0.0000189_JPRB,  &
&   1.6308862_JPRB,     -0.0001731_JPRB,      0.9970861_JPRB,      0.0000004_JPRB,      0.0010026_JPRB,      0.0000272_JPRB,  &
&   1.6346488_JPRB,     -0.0001913_JPRB,      0.9989675_JPRB,      0.0000004_JPRB,      0.0005885_JPRB,      0.0000117_JPRB,  &
&   1.6394585_JPRB,     -0.0002266_JPRB,      1.0010396_JPRB,      0.0000005_JPRB,      0.0001630_JPRB,     -0.0000020_JPRB,  &
&   1.6394585_JPRB,     -0.0002266_JPRB,      1.0010396_JPRB,      0.0000005_JPRB,      0.0001630_JPRB,     -0.0000020_JPRB,  &
&   1.6358005_JPRB,     -0.0001914_JPRB,      1.0016552_JPRB,      0.0000004_JPRB,      0.0001606_JPRB,     -0.0000041_JPRB,  &
&   1.6361767_JPRB,     -0.0001973_JPRB,      1.0015480_JPRB,      0.0000004_JPRB,      0.0001696_JPRB,     -0.0000035_JPRB,  &
&   1.6361277_JPRB,     -0.0001895_JPRB,      1.0020007_JPRB,      0.0000003_JPRB,      0.0000949_JPRB,     -0.0000073_JPRB,  &
&   1.5343256_JPRB,      0.0009690_JPRB,      1.0219324_JPRB,     -0.0000030_JPRB,     -0.0013068_JPRB,     -0.0001376_JPRB,  &
&   1.6354806_JPRB,     -0.0001837_JPRB,      1.0018758_JPRB,      0.0000004_JPRB,      0.0001417_JPRB,     -0.0000054_JPRB,  &
&   1.6375713_JPRB,     -0.0002090_JPRB,      1.0013409_JPRB,      0.0000004_JPRB,      0.0001697_JPRB,     -0.0000028_JPRB,  &
&   1.6389123_JPRB,     -0.0002210_JPRB,      1.0010469_JPRB,      0.0000004_JPRB,      0.0001832_JPRB,     -0.0000016_JPRB,  &
&   1.6364622_JPRB,     -0.0002039_JPRB,      1.0010624_JPRB,      0.0000004_JPRB,      0.0002361_JPRB,     -0.0000006_JPRB/),&
&     SHAPE =(/ n_baran2018_sca, n_baran2018_wn/))
 
  !> Baran regression coefficients for backscattering parameter (bpr)
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_regcoef_bpr(n_baran2018_bpr, n_baran2018_wn) = &
  RESHAPE( (/ &
&        0.5295506_JPRB,     -0.0017205_JPRB,     -0.0592053_JPRB,  &
&        0.5463686_JPRB,     -0.0018094_JPRB,     -0.0620234_JPRB,  &
&        0.5444430_JPRB,     -0.0018357_JPRB,     -0.0625191_JPRB,  &
&        0.5403868_JPRB,     -0.0018670_JPRB,     -0.0636557_JPRB,  &
&        0.5265362_JPRB,     -0.0018715_JPRB,     -0.0647506_JPRB,  &
&        0.5088731_JPRB,     -0.0018508_JPRB,     -0.0654014_JPRB,  &
&        0.4823368_JPRB,     -0.0017885_JPRB,     -0.0654841_JPRB,  &
&        0.4438279_JPRB,     -0.0016909_JPRB,     -0.0664356_JPRB,  &
&        0.4165155_JPRB,     -0.0016140_JPRB,     -0.0661929_JPRB,  &
&        0.4018992_JPRB,     -0.0015745_JPRB,     -0.0658504_JPRB,  &
&        0.3891250_JPRB,     -0.0015377_JPRB,     -0.0654037_JPRB,  &
&        0.4018359_JPRB,     -0.0015711_JPRB,     -0.0640110_JPRB,  &
&        0.4057415_JPRB,     -0.0015405_JPRB,     -0.0600249_JPRB,  &
&        0.3877106_JPRB,     -0.0014714_JPRB,     -0.0598882_JPRB,  &
&        0.3797629_JPRB,     -0.0014452_JPRB,     -0.0600140_JPRB,  &
&        0.3337697_JPRB,     -0.0012543_JPRB,     -0.0558316_JPRB,  &
&        0.3072811_JPRB,     -0.0011258_JPRB,     -0.0533949_JPRB,  &
&        0.2621531_JPRB,     -0.0010168_JPRB,     -0.0528777_JPRB,  &
&        0.2025763_JPRB,     -0.0008781_JPRB,     -0.0503722_JPRB,  &
&        0.2005317_JPRB,     -0.0008927_JPRB,     -0.0508556_JPRB,  &
&        0.1929720_JPRB,     -0.0008602_JPRB,     -0.0485975_JPRB,  &
&        0.1995470_JPRB,     -0.0008873_JPRB,     -0.0488878_JPRB,  &
&        0.1897769_JPRB,     -0.0008416_JPRB,     -0.0469223_JPRB,  &
&        0.1854315_JPRB,     -0.0008167_JPRB,     -0.0446533_JPRB,  &
&        0.1841805_JPRB,     -0.0008004_JPRB,     -0.0425984_JPRB,  &
&        0.1881968_JPRB,     -0.0008016_JPRB,     -0.0407035_JPRB,  &
&        0.1978380_JPRB,     -0.0007922_JPRB,     -0.0366632_JPRB,  &
&        0.2101070_JPRB,     -0.0007746_JPRB,     -0.0322269_JPRB,  &
&        0.2108295_JPRB,     -0.0007161_JPRB,     -0.0270158_JPRB,  &
&        0.2065801_JPRB,     -0.0006720_JPRB,     -0.0245379_JPRB,  &
&        0.2017750_JPRB,     -0.0006472_JPRB,     -0.0237330_JPRB,  &
&        0.2007106_JPRB,     -0.0006228_JPRB,     -0.0218709_JPRB,  &
&        0.2012047_JPRB,     -0.0006165_JPRB,     -0.0212249_JPRB,  &
&        0.1996318_JPRB,     -0.0006118_JPRB,     -0.0210789_JPRB,  &
&        0.1984562_JPRB,     -0.0006114_JPRB,     -0.0211571_JPRB,  &
&        0.1825425_JPRB,     -0.0005975_JPRB,     -0.0218481_JPRB,  &
&        0.1778804_JPRB,     -0.0005830_JPRB,     -0.0213359_JPRB,  &
&        0.1669637_JPRB,     -0.0005549_JPRB,     -0.0211313_JPRB,  &
&        0.1613981_JPRB,     -0.0005364_JPRB,     -0.0206291_JPRB,  &
&        0.1544953_JPRB,     -0.0005063_JPRB,     -0.0194630_JPRB,  &
&        0.1587988_JPRB,     -0.0005240_JPRB,     -0.0201070_JPRB,  &
&        0.1561375_JPRB,     -0.0005188_JPRB,     -0.0202848_JPRB,  &
&        0.1531134_JPRB,     -0.0005048_JPRB,     -0.0199168_JPRB,  &
&        0.1535229_JPRB,     -0.0005054_JPRB,     -0.0199057_JPRB,  &
&        0.1385066_JPRB,     -0.0004520_JPRB,     -0.0189136_JPRB,  &
&        0.1308932_JPRB,     -0.0004102_JPRB,     -0.0172828_JPRB,  &
&        0.1275260_JPRB,     -0.0003955_JPRB,     -0.0168293_JPRB,  &
&        0.1226156_JPRB,     -0.0003747_JPRB,     -0.0163902_JPRB,  &
&        0.1175362_JPRB,     -0.0003540_JPRB,     -0.0158053_JPRB,  &
&        0.1091534_JPRB,     -0.0003063_JPRB,     -0.0143611_JPRB,  &
&        0.1016214_JPRB,     -0.0002658_JPRB,     -0.0129283_JPRB,  &
&        0.0986325_JPRB,     -0.0002495_JPRB,     -0.0122750_JPRB,  &
&        0.0942434_JPRB,     -0.0002261_JPRB,     -0.0112688_JPRB,  &
&        0.0924031_JPRB,     -0.0002167_JPRB,     -0.0108487_JPRB,  &
&        0.0909568_JPRB,     -0.0002092_JPRB,     -0.0104969_JPRB,  &
&        0.0890206_JPRB,     -0.0002003_JPRB,     -0.0100345_JPRB,  &
&        0.0875863_JPRB,     -0.0001947_JPRB,     -0.0097526_JPRB,  &
&        0.0839582_JPRB,     -0.0001816_JPRB,     -0.0091181_JPRB,  &
&        0.0807898_JPRB,     -0.0001747_JPRB,     -0.0087135_JPRB,  &
&        0.0773499_JPRB,     -0.0001685_JPRB,     -0.0083142_JPRB,  &
&        0.0736146_JPRB,     -0.0001634_JPRB,     -0.0079223_JPRB,  &
&        0.0705723_JPRB,     -0.0001586_JPRB,     -0.0073824_JPRB,  &
&        0.0640328_JPRB,     -0.0001511_JPRB,     -0.0065295_JPRB,  &
&        0.0576769_JPRB,     -0.0001468_JPRB,     -0.0060954_JPRB,  &
&        0.0496391_JPRB,     -0.0001455_JPRB,     -0.0066496_JPRB,  &
&        0.0555103_JPRB,     -0.0001779_JPRB,     -0.0075017_JPRB,  &
&        0.0579754_JPRB,     -0.0001861_JPRB,     -0.0075532_JPRB,  &
&        0.0647925_JPRB,     -0.0002062_JPRB,     -0.0078311_JPRB,  &
&        0.0690378_JPRB,     -0.0002156_JPRB,     -0.0079583_JPRB,  &
&        0.0769242_JPRB,     -0.0002373_JPRB,     -0.0087152_JPRB,  &
&        0.0784279_JPRB,     -0.0002422_JPRB,     -0.0089660_JPRB,  &
&        0.0823682_JPRB,     -0.0002573_JPRB,     -0.0096876_JPRB,  &
&        0.0844680_JPRB,     -0.0002658_JPRB,     -0.0100556_JPRB,  &
&        0.0845843_JPRB,     -0.0002677_JPRB,     -0.0102534_JPRB,  &
&        0.0860361_JPRB,     -0.0002732_JPRB,     -0.0105088_JPRB,  &
&        0.0847631_JPRB,     -0.0002702_JPRB,     -0.0106223_JPRB,  &
&        0.0813323_JPRB,     -0.0002600_JPRB,     -0.0106050_JPRB,  &
&        0.0775648_JPRB,     -0.0002491_JPRB,     -0.0105942_JPRB,  &
&        0.0740292_JPRB,     -0.0002348_JPRB,     -0.0101513_JPRB,  &
&        0.0687879_JPRB,     -0.0002135_JPRB,     -0.0094718_JPRB,  &
&        0.0659706_JPRB,     -0.0002018_JPRB,     -0.0090406_JPRB,  &
&        0.0644756_JPRB,     -0.0001957_JPRB,     -0.0088306_JPRB,  &
&        0.0635377_JPRB,     -0.0001914_JPRB,     -0.0086414_JPRB,  &
&        0.0607576_JPRB,     -0.0001810_JPRB,     -0.0083236_JPRB,  &
&        0.0573257_JPRB,     -0.0001689_JPRB,     -0.0077697_JPRB,  &
&        0.0669622_JPRB,     -0.0002121_JPRB,     -0.0089765_JPRB,  &
&        0.0736715_JPRB,     -0.0002384_JPRB,     -0.0097332_JPRB,  &
&        0.0910080_JPRB,     -0.0003001_JPRB,     -0.0114368_JPRB,  &
&        0.1109842_JPRB,     -0.0003621_JPRB,     -0.0130906_JPRB,  &
&        0.1134381_JPRB,     -0.0003690_JPRB,     -0.0133234_JPRB,  &
&        0.1156123_JPRB,     -0.0003824_JPRB,     -0.0142937_JPRB,  &
&        0.1411101_JPRB,     -0.0004478_JPRB,     -0.0152190_JPRB,  &
&        0.1183217_JPRB,     -0.0003849_JPRB,     -0.0143075_JPRB,  &
&        0.0990684_JPRB,     -0.0003013_JPRB,     -0.0111292_JPRB,  &
&        0.1115547_JPRB,     -0.0003487_JPRB,     -0.0127669_JPRB,  &
&        0.1248343_JPRB,     -0.0004042_JPRB,     -0.0146931_JPRB,  &
&        0.1486285_JPRB,     -0.0004693_JPRB,     -0.0160057_JPRB,  &
&        0.1624163_JPRB,     -0.0005122_JPRB,     -0.0174479_JPRB,  &
&        0.1598173_JPRB,     -0.0005125_JPRB,     -0.0182308_JPRB,  &
&        0.1380756_JPRB,     -0.0004518_JPRB,     -0.0176440_JPRB,  &
&        0.1018242_JPRB,     -0.0003024_JPRB,     -0.0131672_JPRB,  &
&        0.0720719_JPRB,     -0.0001581_JPRB,     -0.0074581_JPRB,  &
&        0.0771788_JPRB,     -0.0001214_JPRB,     -0.0035313_JPRB,  &
&        0.0715713_JPRB,     -0.0000944_JPRB,     -0.0035499_JPRB,  &
&        0.0767097_JPRB,     -0.0000877_JPRB,     -0.0030490_JPRB,  &
&        0.0803117_JPRB,     -0.0000821_JPRB,     -0.0027825_JPRB,  &
&        0.0915042_JPRB,     -0.0001017_JPRB,     -0.0022817_JPRB,  &
&        0.0886400_JPRB,     -0.0000782_JPRB,     -0.0023010_JPRB,  &
&        0.0939796_JPRB,     -0.0000673_JPRB,     -0.0017332_JPRB,  &
&        0.0984249_JPRB,     -0.0000648_JPRB,     -0.0014554_JPRB,  &
&        0.0957513_JPRB,     -0.0000680_JPRB,     -0.0013343_JPRB,  &
&        0.0867182_JPRB,     -0.0000555_JPRB,     -0.0010976_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB,  &
&        0.0000000_JPRB,      0.0000000_JPRB,      0.0000000_JPRB/),&
&     SHAPE =(/ n_baran2018_bpr, n_baran2018_wn/))
 
  !> Baran regression coefficients for asymmetry parameter
  REAL(KIND=JPRB), PUBLIC, PARAMETER :: baran2018_regcoef_asym(n_baran2018_asym, n_baran2018_wn) = &
  RESHAPE( (/ &
&        0.1851888_JPRB,      0.0027943_JPRB,      0.1116049_JPRB,  &
&        0.1549269_JPRB,      0.0029631_JPRB,      0.1182803_JPRB,  &
&        0.1689456_JPRB,      0.0029462_JPRB,      0.1174533_JPRB,  &
&        0.1876625_JPRB,      0.0029264_JPRB,      0.1172407_JPRB,  &
&        0.2228329_JPRB,      0.0028502_JPRB,      0.1157894_JPRB,  &
&        0.2590021_JPRB,      0.0027536_JPRB,      0.1136989_JPRB,  &
&        0.3023100_JPRB,      0.0026173_JPRB,      0.1103791_JPRB,  &
&        0.3537149_JPRB,      0.0024676_JPRB,      0.1082107_JPRB,  &
&        0.3845779_JPRB,      0.0023754_JPRB,      0.1053111_JPRB,  &
&        0.4010877_JPRB,      0.0023300_JPRB,      0.1035511_JPRB,  &
&        0.4150000_JPRB,      0.0022903_JPRB,      0.1019176_JPRB,  &
&        0.4001342_JPRB,      0.0023225_JPRB,      0.0996651_JPRB,  &
&        0.3992579_JPRB,      0.0022462_JPRB,      0.0924022_JPRB,  &
&        0.4238914_JPRB,      0.0021466_JPRB,      0.0916819_JPRB,  &
&        0.4326922_JPRB,      0.0021179_JPRB,      0.0916230_JPRB,  &
&        0.4925293_JPRB,      0.0018476_JPRB,      0.0824583_JPRB,  &
&        0.5300032_JPRB,      0.0016558_JPRB,      0.0780274_JPRB,  &
&        0.5776457_JPRB,      0.0015892_JPRB,      0.0775081_JPRB,  &
&        0.6589656_JPRB,      0.0014650_JPRB,      0.0772629_JPRB,  &
&        0.6618937_JPRB,      0.0014961_JPRB,      0.0785411_JPRB,  &
&        0.6737518_JPRB,      0.0014511_JPRB,      0.0755614_JPRB,  &
&        0.6627230_JPRB,      0.0014933_JPRB,      0.0755811_JPRB,  &
&        0.6784281_JPRB,      0.0014250_JPRB,      0.0730418_JPRB,  &
&        0.6855613_JPRB,      0.0013898_JPRB,      0.0700378_JPRB,  &
&        0.6879440_JPRB,      0.0013659_JPRB,      0.0672601_JPRB,  &
&        0.6808605_JPRB,      0.0013717_JPRB,      0.0644730_JPRB,  &
&        0.6642629_JPRB,      0.0013611_JPRB,      0.0583832_JPRB,  &
&        0.6446730_JPRB,      0.0013286_JPRB,      0.0514417_JPRB,  &
&        0.6452605_JPRB,      0.0012310_JPRB,      0.0440540_JPRB,  &
&        0.6536691_JPRB,      0.0011570_JPRB,      0.0406974_JPRB,  &
&        0.6619728_JPRB,      0.0011162_JPRB,      0.0395885_JPRB,  &
&        0.6648831_JPRB,      0.0010741_JPRB,      0.0370044_JPRB,  &
&        0.6643469_JPRB,      0.0010629_JPRB,      0.0360259_JPRB,  &
&        0.6670246_JPRB,      0.0010552_JPRB,      0.0358238_JPRB,  &
&        0.6689234_JPRB,      0.0010554_JPRB,      0.0359835_JPRB,  &
&        0.6949590_JPRB,      0.0010404_JPRB,      0.0374733_JPRB,  &
&        0.7028606_JPRB,      0.0010167_JPRB,      0.0366729_JPRB,  &
&        0.7214891_JPRB,      0.0009705_JPRB,      0.0364523_JPRB,  &
&        0.7310836_JPRB,      0.0009395_JPRB,      0.0356618_JPRB,  &
&        0.7430462_JPRB,      0.0008880_JPRB,      0.0337336_JPRB,  &
&        0.7355958_JPRB,      0.0009182_JPRB,      0.0347969_JPRB,  &
&        0.7402210_JPRB,      0.0009095_JPRB,      0.0351265_JPRB,  &
&        0.7454476_JPRB,      0.0008854_JPRB,      0.0345097_JPRB,  &
&        0.7447460_JPRB,      0.0008864_JPRB,      0.0344883_JPRB,  &
&        0.7709712_JPRB,      0.0007945_JPRB,      0.0329041_JPRB,  &
&        0.7842521_JPRB,      0.0007222_JPRB,      0.0301405_JPRB,  &
&        0.7901911_JPRB,      0.0006966_JPRB,      0.0293821_JPRB,  &
&        0.7988284_JPRB,      0.0006602_JPRB,      0.0286462_JPRB,  &
&        0.8078339_JPRB,      0.0006240_JPRB,      0.0276640_JPRB,  &
&        0.8224811_JPRB,      0.0005410_JPRB,      0.0251832_JPRB,  &
&        0.8358004_JPRB,      0.0004700_JPRB,      0.0227262_JPRB,  &
&        0.8411079_JPRB,      0.0004413_JPRB,      0.0216033_JPRB,  &
&        0.8489682_JPRB,      0.0003999_JPRB,      0.0198720_JPRB,  &
&        0.8522904_JPRB,      0.0003832_JPRB,      0.0191478_JPRB,  &
&        0.8548987_JPRB,      0.0003697_JPRB,      0.0185397_JPRB,  &
&        0.8584062_JPRB,      0.0003539_JPRB,      0.0177371_JPRB,  &
&        0.8610385_JPRB,      0.0003436_JPRB,      0.0172470_JPRB,  &
&        0.8676360_JPRB,      0.0003195_JPRB,      0.0161310_JPRB,  &
&        0.8734733_JPRB,      0.0003060_JPRB,      0.0153989_JPRB,  &
&        0.8797387_JPRB,      0.0002935_JPRB,      0.0146516_JPRB,  &
&        0.8864488_JPRB,      0.0002831_JPRB,      0.0138944_JPRB,  &
&        0.8919155_JPRB,      0.0002731_JPRB,      0.0128752_JPRB,  &
&        0.9038114_JPRB,      0.0002556_JPRB,      0.0112225_JPRB,  &
&        0.9156259_JPRB,      0.0002411_JPRB,      0.0102551_JPRB,  &
&        0.9304165_JPRB,      0.0002282_JPRB,      0.0108593_JPRB,  &
&        0.9213451_JPRB,      0.0002784_JPRB,      0.0122520_JPRB,  &
&        0.9172354_JPRB,      0.0002925_JPRB,      0.0123699_JPRB,  &
&        0.9053992_JPRB,      0.0003302_JPRB,      0.0129873_JPRB,  &
&        0.8976548_JPRB,      0.0003503_JPRB,      0.0133280_JPRB,  &
&        0.8832493_JPRB,      0.0003943_JPRB,      0.0148327_JPRB,  &
&        0.8804979_JPRB,      0.0004039_JPRB,      0.0153049_JPRB,  &
&        0.8734266_JPRB,      0.0004322_JPRB,      0.0166424_JPRB,  &
&        0.8696879_JPRB,      0.0004479_JPRB,      0.0173269_JPRB,  &
&        0.8694825_JPRB,      0.0004513_JPRB,      0.0176819_JPRB,  &
&        0.8668537_JPRB,      0.0004617_JPRB,      0.0181623_JPRB,  &
&        0.8690679_JPRB,      0.0004563_JPRB,      0.0183531_JPRB,  &
&        0.8751014_JPRB,      0.0004378_JPRB,      0.0182854_JPRB,  &
&        0.8817230_JPRB,      0.0004178_JPRB,      0.0182207_JPRB,  &
&        0.8878642_JPRB,      0.0003924_JPRB,      0.0174023_JPRB,  &
&        0.8969418_JPRB,      0.0003546_JPRB,      0.0161523_JPRB,  &
&        0.9018132_JPRB,      0.0003337_JPRB,      0.0153642_JPRB,  &
&        0.9043907_JPRB,      0.0003230_JPRB,      0.0149789_JPRB,  &
&        0.9060041_JPRB,      0.0003154_JPRB,      0.0146366_JPRB,  &
&        0.9107886_JPRB,      0.0002969_JPRB,      0.0140457_JPRB,  &
&        0.9168034_JPRB,      0.0002743_JPRB,      0.0130070_JPRB,  &
&        0.9007108_JPRB,      0.0003473_JPRB,      0.0151445_JPRB,  &
&        0.8891233_JPRB,      0.0003940_JPRB,      0.0165467_JPRB,  &
&        0.8584235_JPRB,      0.0005075_JPRB,      0.0198056_JPRB,  &
&        0.8219616_JPRB,      0.0006258_JPRB,      0.0229466_JPRB,  &
&        0.8174221_JPRB,      0.0006393_JPRB,      0.0233732_JPRB,  &
&        0.8134427_JPRB,      0.0006635_JPRB,      0.0250704_JPRB,  &
&        0.7668604_JPRB,      0.0007863_JPRB,      0.0266353_JPRB,  &
&        0.8081666_JPRB,      0.0006706_JPRB,      0.0251204_JPRB,  &
&        0.8426998_JPRB,      0.0005203_JPRB,      0.0195128_JPRB,  &
&        0.8200990_JPRB,      0.0006072_JPRB,      0.0224451_JPRB,  &
&        0.7962832_JPRB,      0.0007066_JPRB,      0.0257899_JPRB,  &
&        0.7534397_JPRB,      0.0008244_JPRB,      0.0279224_JPRB,  &
&        0.7294109_JPRB,      0.0008976_JPRB,      0.0302464_JPRB,  &
&        0.7338828_JPRB,      0.0008983_JPRB,      0.0316033_JPRB,  &
&        0.7720130_JPRB,      0.0007934_JPRB,      0.0307749_JPRB,  &
&        0.8366359_JPRB,      0.0005288_JPRB,      0.0231502_JPRB,  &
&        0.8892020_JPRB,      0.0002733_JPRB,      0.0130474_JPRB,  &
&        0.8800176_JPRB,      0.0002108_JPRB,      0.0061699_JPRB,  &
&        0.8897492_JPRB,      0.0001641_JPRB,      0.0062252_JPRB,  &
&        0.8801830_JPRB,      0.0001562_JPRB,      0.0055227_JPRB,  &
&        0.8727148_JPRB,      0.0001500_JPRB,      0.0049954_JPRB,  &
&        0.8536847_JPRB,      0.0001802_JPRB,      0.0040333_JPRB,  &
&        0.8589215_JPRB,      0.0001376_JPRB,      0.0040478_JPRB,  &
&        0.8496447_JPRB,      0.0001180_JPRB,      0.0030349_JPRB,  &
&        0.8419617_JPRB,      0.0001131_JPRB,      0.0025385_JPRB,  &
&        0.8465603_JPRB,      0.0001191_JPRB,      0.0023360_JPRB,  &
&        0.8623170_JPRB,      0.0000977_JPRB,      0.0019314_JPRB,  &
&        0.8778459_JPRB,      0.0000927_JPRB,      0.0018021_JPRB,  &
&        0.8905257_JPRB,      0.0000948_JPRB,      0.0020659_JPRB,  &
&        0.9410098_JPRB,      0.0001140_JPRB,      0.0034609_JPRB,  &
&        0.9525716_JPRB,      0.0001402_JPRB,      0.0045444_JPRB,  &
&        0.9520232_JPRB,      0.0001632_JPRB,      0.0052411_JPRB,  &
&        0.9347847_JPRB,      0.0002116_JPRB,      0.0055922_JPRB,  &
&        0.8746641_JPRB,      0.0003816_JPRB,      0.0091081_JPRB,  &
&        0.8044567_JPRB,      0.0004355_JPRB,      0.0101626_JPRB,  &
&        0.7900056_JPRB,      0.0004257_JPRB,      0.0108394_JPRB,  &
&        0.7701907_JPRB,      0.0004193_JPRB,      0.0111116_JPRB,  &
&        0.7820739_JPRB,      0.0002936_JPRB,      0.0087696_JPRB,  &
&        0.7568061_JPRB,      0.0004511_JPRB,      0.0133549_JPRB,  &
&        0.7562644_JPRB,      0.0006703_JPRB,      0.0212950_JPRB,  &
&        0.7468803_JPRB,      0.0007232_JPRB,      0.0228591_JPRB,  &
&        0.7507063_JPRB,      0.0005909_JPRB,      0.0190169_JPRB,  &
&        0.7562378_JPRB,      0.0003511_JPRB,      0.0117171_JPRB,  &
&        0.7622226_JPRB,      0.0003414_JPRB,      0.0118827_JPRB,  &
&        0.7400044_JPRB,      0.0005108_JPRB,      0.0156280_JPRB,  &
&        0.7530717_JPRB,      0.0003983_JPRB,      0.0124300_JPRB,  &
&        0.7676701_JPRB,      0.0001860_JPRB,      0.0072189_JPRB,  &
&        0.7752351_JPRB,      0.0001563_JPRB,      0.0066437_JPRB,  &
&        0.7750628_JPRB,      0.0001456_JPRB,      0.0068096_JPRB,  &
&        0.7758680_JPRB,      0.0001373_JPRB,      0.0065790_JPRB,  &
&        0.7729453_JPRB,      0.0001434_JPRB,      0.0071777_JPRB,  &
&        0.7729453_JPRB,      0.0001434_JPRB,      0.0071777_JPRB,  &
&        0.7732092_JPRB,      0.0001333_JPRB,      0.0068154_JPRB,  &
&        0.7717055_JPRB,      0.0001287_JPRB,      0.0066530_JPRB,  &
&        0.7696181_JPRB,      0.0001293_JPRB,      0.0066801_JPRB,  &
&        0.7681362_JPRB,      0.0001270_JPRB,      0.0064771_JPRB,  &
&        0.7645441_JPRB,      0.0001235_JPRB,      0.0064520_JPRB,  &
&        0.7550029_JPRB,      0.0001242_JPRB,      0.0066489_JPRB,  &
&        0.7446464_JPRB,      0.0001175_JPRB,      0.0064077_JPRB,  &
&        0.7322924_JPRB,      0.0001154_JPRB,      0.0061708_JPRB/),&
&     SHAPE =(/ n_baran2018_asym, n_baran2018_wn/))
 
END MODULE mod_rttov_baran2018_icldata
